<?php
$cb;
add_action( 'init', 'infinite_twitter_api' );
function infinite_twitter_api() {
	global $cb;
	$consumer_key = of_get_option('infinite_twitter_consumer_key', false);
	$consumer_secret = of_get_option('infinite_twitter_consumer_secret', false);
	$access_token = of_get_option('infinite_twitter_access_token', false);
	$access_secret = of_get_option('infinite_twitter_access_token_secret', false);

	include( 'codebird.php' );
	if(!$consumer_key || !$consumer_secret || !$access_token || !$access_secret) return;
	\Codebird\Codebird::setConsumerKey( $consumer_key, $consumer_secret );
	$cb = \Codebird\Codebird::getInstance();
	$cb->setToken( $access_token, $access_secret );
}



add_action('widgets_init', 'infinite_twitter_widget');

function infinite_twitter_widget()
{
	register_widget('infinite_Twitter_Widget');
}

class infinite_Twitter_Widget extends WP_Widget {
	
	function infinite_Twitter_Widget()
	{
		$widget_ops = array('classname' => 'infinite-twitter', 'description' => 'Display your tweets from twitter');

		$control_ops = array('id_base' => 'infinite-twitter-widget');

		$this->WP_Widget('infinite-twitter-widget', 'Infinite Twitter', $widget_ops, $control_ops);

		wp_register_script( 'twitter', ( '//platform.twitter.com/widgets.js' ), false, null, true );
    	wp_enqueue_script( 'twitter' );
	}
	
	function widget($args, $instance)
	{
		$tweets = $this->get_tweets( $args['widget_id'], $instance );

		echo $args['before_widget'];
		echo $args['before_title'] . $instance['title'] .  $args['after_title'];

		echo $tweets;

		echo $args['after_widget'];
	}
	
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;

		$instance['title'] = strip_tags($new_instance['title']);
		$instance['limit'] = $new_instance['limit'];
		$instance['username'] = $new_instance['username'];
		
		return $instance;
	}

	function form($instance)
	{
		$defaults = array(
			'title'    => '',
			'limit'    => 5,
			'username' => 'twitter'
		);
	$values = wp_parse_args( $instance, $defaults );
	?>
		<p>
			<label for='<?php echo $this->get_field_id( 'title' ); ?>'>
				<?php _e( 'Title:', 'mytextdomain' ); ?>
				<input class='widefat' id='<?php echo $this->get_field_id( 'title' ); ?>' name='<?php echo $this->get_field_name( 'title' ); ?>' type='text' value='<?php echo $values['title']; ?>' />
			</label>
		</p>

		<p>
			<label for='<?php echo $this->get_field_id( 'limit' ); ?>'>
				<?php _e( 'Tweets to show:', 'mytextdomain' ); ?>
				<input class='widefat' id='<?php echo $this->get_field_id( 'limit' ); ?>' name='<?php echo $this->get_field_name( 'limit' ); ?>' type='text' value='<?php echo $values['limit']; ?>' />
			</label>
		</p>

		<p>
			<label for='<?php echo $this->get_field_id( 'username' ); ?>'>
				<?php _e( 'Twitter user name:', 'mytextdomain' ); ?>
				<input class='widefat' id='<?php echo $this->get_field_id( 'username' ); ?>' name='<?php echo $this->get_field_name( 'username' ); ?>' type='text' value='<?php echo $values['username']; ?>' />
			</label>
		</p>

	<?php
	}

	function retrieve_tweets( $widget_id, $instance ) {
		global $cb;
		if($cb == null) return null;
	 	$timeline = $cb->statuses_userTimeline( 'screen_name=' . $instance['username']. '&count=' . $instance['limit'] . '&exclude_replies=true' );
	 	return $timeline;
	}

	function save_tweets( $widget_id, $instance ) {
		try{
			$tweets = $this->retrieve_tweets( $widget_id, $instance );
		}catch(Exception $e){
			$tweets = null;
		}	
		$tweets = $this->process_tweets($tweets);
		set_transient('infinite_tweets_' . $widget_id, $tweets, 60 * 5 );
		return $tweets;
	}

	function get_tweets( $widget_id, $instance ) {
		$tweets = get_transient('infinite_tweets_' . $widget_id);
		if( !$tweets OR empty($tweets)) {
			$tweets = $this->save_tweets( $widget_id, $instance );
		}
		return $tweets;
	}

	function Timesince($original) {
	    // array of time period chunks
	    $chunks = array(
	    array(60 * 60 * 24 , 'day'),
	    array(60 * 60 , 'h'),
	    array(60 , 'm'),
	    array(1 , 's'),
	    );
	 
	    $today = time(); /* Current unix time  */
	    $since = $today - $original;
	 
	    // $j saves performing the count function each time around the loop
	    for ($i = 0, $j = count($chunks); $i < $j; $i++) {
	 
		    $seconds = $chunks[$i][0];
		    $name = $chunks[$i][1];
		 
		    // finding the biggest chunk (if the chunk fits, break)
		    if (($count = floor($since / $seconds)) != 0) {
		    	if($name == 'day') return date('j M',$original);
		        break;
		    }
	    }
	 
	    $print = $count.$name;
	 
	    if ($i + 1 < $j) {
	    // now getting the second item
	    $seconds2 = $chunks[$i + 1][0];
	    $name2 = $chunks[$i + 1][1];
	 
	    }
	    return $print;
	}

	function process_tweets($tweets){

		if($tweets == null) return ;

		$html = '';

		if( !empty($tweets) AND empty($tweets->errors) ) {
			$html .= '<ul>';

			foreach ($tweets as $ind => $tweet) {
				if(is_object( $tweet )){
					$tweet_text = htmlentities($tweet->text, ENT_QUOTES, 'UTF-8');
					$urls = $tweet->entities->urls;
					if(empty($urls) && !empty($tweet->entities->media)) $urls = $tweet->entities->media;
					if(empty($urls) && !empty($tweet->retweeted_status->entities->urls)) $urls = $tweet->retweeted_status->entities->urls;
					if(empty($urls) && !empty($tweet->retweeted_status->entities->media)) $urls = $tweet->retweeted_status->entities->media;

					if(!empty($urls)){
						preg_match('/http:\/\/([a-z0-9_\.\-\+\&\!\#\~\/\,]+)/i', $tweet_text, $http);
						if(!empty($http)){
							for ($i=0; $i < count($http) ; $i = $i+2) {
								foreach ($urls  as $url) {
									if($url->url == $http[$i]){
										$tweet_text = str_replace($url->url,'<a href="'. $url->url .'" title="'.$url->expanded_url.'">'.$url->display_url.'</a>', $tweet_text);
									}
								}
							}
						}

						preg_match('/https:\/\/([a-z0-9_\.\-\+\&\!\#\~\/\,]+)/i', $tweet_text, $https);

						if(!empty($https)){
							for ($i=0; $i < count($https) ; $i = $i+2) {
								foreach ($urls  as $url) {
									if($url->url == $https[$i]){
										$tweet_text = str_replace($url->url,'<a href="'. $url->url .'" title="'.$url->expanded_url.'">'.$url->display_url.'</a>', $tweet_text);
									}
								}
							}
						}

					}else{
						$tweet_text = preg_replace( '/http:\/\/([a-z0-9_\.\-\+\&\!\#\~\/\,]+)/i', '<a href="http://$1">$1</a>', $tweet_text );
						$tweet_text = preg_replace( '/https:\/\/([a-z0-9_\.\-\+\&\!\#\~\/\,]+)/i', '<a href="https://$1">$1</a>', $tweet_text );
					}

					$tweet_text = preg_replace( '/@([a-z0-9_\.\-\+\&\!\#\~\/\,]+)/i', '<a href="https://twitter.com/$1">@$1</a>', $tweet_text );
					$tweet_text = preg_replace( '/\s\#([a-z0-9_\.\-\+\&\!\#\~\/\,]+)/i', '<a href="https://twitter.com/search?q=%23$1&src=hash">#$1</a>', $tweet_text );
					$icon = $tweet->favorited ? 'icon-star' : 'icon-star-empty';
					$html .= '<li>
							<a class="profile-link" href="https://twitter.com/'.$tweet->user->screen_name.'">
								<div class="twitter-avatar"><img src="' . $tweet->user->profile_image_url . '"></div>
								<span class="twitter-username">'.$tweet->user->name.'</span>
								<span class="twitter-screenname"> @'.$tweet->user->screen_name.'</span>
							</a>
							<div class="tweet-content">'.$tweet_text.'</div>
							<span class="tweet-time">'.$this->Timesince(strtotime( $tweet->created_at )).'</span>
							<span class="tweet-actions">
								<a class="twitter-reply" href="https://twitter.com/intent/tweet?in_reply_to='.$tweet->id_str.'"><i class="icon-reply"></i></a>
								<a class="twitter-retweet" href="https://twitter.com/intent/retweet?tweet_id='.$tweet->id_str.'"><i class="icon-retweet"></i></a>
								<a class="twitter-favorite" href="https://twitter.com/intent/favorite?tweet_id='.$tweet->id_str.'"><i class="'.$icon.'"></i></a>
							</span>
						  </li>';
				}
			}
			$html .= '</ul>';
		}

		return $html ;
	}

}
?>