<?php
/*****************************************************************************************************/
/* DEFINE CONSTANTS */
/*****************************************************************************************************/
define('THEMEROOT', get_stylesheet_directory_uri());
define('IMAGES', THEMEROOT.'/images');
define('PRODUCTION_ENV', true);

$infinite_config = array();
$infinite_config['RevSlider'] = array();
$infinite_config['RevSliderAllSliders'] = array('' => '');

if(class_exists('RevSlider')){
    $rs = new RevSlider();
    $infinite_config['RevSlider'] = $rs->getAllSliderAliases();
    
    foreach ($infinite_config['RevSlider'] as $alias) {
        $infinite_config['RevSliderAllSliders'][$alias] = $alias;
    }
}

if ( ! isset( $content_width ) ) $content_width = 960;

include 'framework/widgets/widgets.php';
include 'framework/portfolio/portfolio-type.php';
include 'framework/shortcodes/shortcodes-framework.php';
include 'framework/metaboxes/metaboxes.php';



if ( !function_exists( 'optionsframework_init' ) ) {
    define( 'OPTIONS_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/framework/options-framework/' );
    require_once dirname( __FILE__ ) . '/framework/options-framework/options-framework.php';
}

include 'framework/sidebar/sidebar.php';
include 'woocommerce/config.php';
include 'bbpress/config.php';

include 'framework/updates/update_notifier.php';
include 'framework/plugin-framework/plugin-framework.php';

include 'framework/thumbnails/ajax-thumbnail-rebuild.php';



if(function_exists('add_theme_support')){
    //add_theme_support('post-formats',array('link', 'quote', 'gallery'));

    // Add post thumbnail functionality
    add_theme_support('post-thumbnails');
    add_image_size('blog-grid', 270, 210, true);
    add_image_size('blog-full', 1170, 470, true);
    add_image_size('blog-normal', 810, 325, true);
    add_image_size('blog-medium', 390, 180, true);
    add_image_size('blog-two-column', 550, 410, true);
    add_image_size('blog-three-column', 390, 290, true);
    add_image_size('blog-four-column', 270, 200, true);
    add_image_size('related-post', 210, 171, true);
    add_image_size('thumb-large', 120, 120, true);
    add_image_size('post-thumb', 80, 80, true);
}



add_theme_support( 'automatic-feed-links' ); 

add_action( 'admin_enqueue_scripts', 'admin_custom_js' );

add_action( 'wp_enqueue_scripts', 'infinite_load_javascript_files' );


function infinite_load_javascript_files(){

    if(PRODUCTION_ENV){

        wp_enqueue_script( 'infinite_all', get_stylesheet_directory_uri() . '/js/infinite.allscripts.min.js', array('jquery'), '1.0', true );

    }else{

        wp_enqueue_script('modernizr', get_stylesheet_directory_uri().'/js/modernizr.custom.js');
        wp_enqueue_script( 'flexSlider', get_stylesheet_directory_uri() . '/js/jquery.flexslider.min.js', array('jquery'), '1.0', true );
        wp_enqueue_script( 'fitvids', get_stylesheet_directory_uri() . '/js/jquery.fitvids.min.js', array('jquery'), '1.0', true );
        wp_enqueue_script( 'isotope', get_stylesheet_directory_uri() . '/js/jquery.isotope.min.js', array('jquery'), '1.5.25', true );
        wp_enqueue_script( 'colorbox', get_stylesheet_directory_uri() . '/js/jquery.colorbox-min.js', array('jquery'), '1.4.24', true );

        wp_enqueue_script( 'bootstrap', get_stylesheet_directory_uri() . '/js/bootstrap.min.js', '', '1.0', true );
        wp_enqueue_script( 'staple', get_stylesheet_directory_uri() . '/js/jquery.staple.min.js', array('jquery'), '1.0', true );
        wp_enqueue_script( 'infinite', get_stylesheet_directory_uri() . '/js/infinite.js', array('jquery'), '1.0', true );

    }

}



function admin_custom_js () {
    wp_register_script( 'infinite_custom_js', get_stylesheet_directory_uri() .'/js/admin.js', array( 'jquery', 'wp-color-picker') );
    wp_enqueue_script( 'infinite_custom_js' );

    wp_enqueue_style( 'wp-color-picker' );

    wp_register_style ('admin_panel_font', get_stylesheet_directory_uri() . '/css/font-awesome.css');
    wp_register_style ('admin_panel_css', get_stylesheet_directory_uri() . '/css/admin.css');
    wp_enqueue_style ('admin_panel_font');
    wp_enqueue_style ('admin_panel_css');

}

/*Localization*/
add_action('after_setup_theme', 'infinite_localization');
function infinite_localization(){
    load_theme_textdomain('infinite-framework', get_template_directory() . '/languages');
}

/*Filter for Custom excerpt*/
add_filter( 'excerpt_more', 'new_excerpt_more' );
function new_excerpt_more( $more ) {
    return ' [...] <a class="read-more" href="'. get_permalink( get_the_ID() ) . '">Read More <i class="icon-double-angle-right"></i></a>';
}


/*****************************************************************************************************/
/* infinite EDITOR OPTIONS */
/*****************************************************************************************************/

//add_action('init', 'add_infinite_buttons');

$infinite_mce_buttons = array("action", "youtube", "vimeo", "section", "row", "onefull", "onehalf", "onethird", "twothird", "onefourth", "twofourth", "threefourth", "slider", 
                                "icon", "button", "pricingtable", "tabs", "toggle", "progress", "testimonial", "alert", "tooltip", "dropcap");

function add_infinite_buttons() {
   if ( current_user_can('edit_posts') &&  current_user_can('edit_pages') ) {
        add_filter('mce_external_plugins', 'add_plugin');
        add_filter('mce_buttons_3', 'register_button');
        add_editor_style( 'admin.css' );
   }
}


function register_button($buttons) {
   global $infinite_mce_buttons;
   return array_merge($buttons, $infinite_mce_buttons);
}


function add_plugin($plugin_array) {
   global $infinite_mce_buttons;

   foreach ($infinite_mce_buttons as $name) {
       $plugin_array[$name] =  get_template_directory_uri().'/js/mce/infinite.mce.js';
   }

   return $plugin_array;
}



/*****************************************************************************************************/
/* MENUS */
/*****************************************************************************************************/

function register_my_menus(){
	register_nav_menus(array(
		'main-menu' => __('Main Menu','infinite-framework') 
	));
}

add_action('init', 'register_my_menus');

class infinite_mob_menu extends Walker_Nav_Menu {
  
    // add classes to ul sub-menus
    function start_lvl( &$output, $depth ) {
        // depth dependent classes
        $indent = ( $depth > 0  ? str_repeat( "\t", $depth ) : '' ); // code indent
        $display_depth = ( $depth + 1); // because it counts the first submenu as 0
      
        // build html
        $output .= "\n" . $indent . '<ul class="dl-submenu">' . "\n";
    }
      
   
}




//add_filter('wp_list_categories', 'add_right_angle_icon');

function add_right_angle_icon($links) {
    $links = str_replace('<a', '<i class="icon-angle-right"></i> <a', $links);
    return $links;
}

function infinite_get_option($name, $default=false){
    $infinite_options = get_option('infinite');
    if($infinite_options && array_key_exists($name, $infinite_options) && !empty($infinite_options[$name]))
        return $infinite_options[$name];
    else if(!$default)
        return;
    else
        return $default;
}

// Filter wp_nav_menu() to add additional links and other output
function new_nav_menu_items($items) {
    $items .= '<li class="menu-item" id="menu-item-search"><a href="#"><i class="icon-search"></i></a><form class="search" action="'.get_site_url().'" method="get"><div class="arrow-up"></div><input name="s" type="text" placeholder="Search ..."></form></li>';
    return $items;
}
add_filter( 'wp_nav_menu_items', 'new_nav_menu_items' );


/*****************************************************************************************************/
/* FUNCTION TO DISPLAY COMMENTS */
/*****************************************************************************************************/

function infinite_comments($comment, $args, $depth){

    $GLOBALS['comment'] = $comment;

    if(get_comment_type() == 'pingback' || get_comment_type() == 'trackback') : ?>
    
        <li class="pingback" id="comment-<?php comment_ID() ?>">
            <article <?php comment_class('clearfix') ?>>
                <div class="comment-meta">
                    <?php _e('Pingback:','infinite-framework') ?>
                    <?php edit_comment_link() ?>
                </div>
                <div class="comment-content">
                    <?php comment_author_link(); ?>
                </div>
            </article>
        </li>
    
    <?php elseif(get_comment_type() == 'comment') : ?>
    
        <li id="comment-<?php comment_ID() ?>">
            <article <?php comment_class('clearfix') ?>>
                <div class="avatar">
                    <?php  echo get_avatar($comment, 70);    ?>
                </div>
                <div class="comment-meta">
                    <?php $author_url = get_comment_author_url();
                        if(empty( $author_url ) || 'http://' == $author_url) : ?>
                        <i class="icon-user"></i>
                        <span class="comment-author"><?php comment_author(); ?></span>
                    <?php else :?>
                        <i class="icon-user"></i>
                        <a class="comment-author" href="<?php $author_url; ?>"><?php comment_author(); ?></a>
                    <?php endif; ?>
                    <!-- <a class="comment-author" href="">Admin</a> -->
                    <span class="comment-date post-date"><i class="icon-calendar"></i> <?php comment_date(); ?> at <?php comment_time(); ?></span>
                    <span class="comment-reply">
                        <i class="icon-reply"></i>
                        <?php comment_reply_link(array_merge($args, array('depth' => $depth, 'max_depth' => $args['max_depth']))); ?>
                    </span>
                </div>
                <div class="comment-content">
                    <?php if($comment->comment_approved == '0') : ?>
                        <p><?php _e('Your comment is awaiting moderation','infinite-framework') ?></p>
                    <?php endif; ?>
                    <?php comment_text(); ?>
                </div>
            </article>

    <?php endif; ?>

<?php
}

function infinite_custom_comment_fields() {
    $commenter = wp_get_current_commenter();
    $req = get_option('require_name_email');
    $aria_req = ($req ? " aria-required='true'" : ' ');
}

add_filter( 'comment_form_default_fields', 'infinite_custom_comment_fields');


/*****************************************************************************************************/
/* PAGINATION/BREADCRUMB FUNCTIONS BY KRIESI */
/*****************************************************************************************************/

function kriesi_pagination($pages = '', $range = 2){  
     $showitems = ($range * 2)+1;  

     global $paged;
     if(empty($paged)) $paged = 1;

     if($pages == '') 
     {
         global $wp_query;
         $pages = $wp_query->max_num_pages;
         if(!$pages)
         {
             $pages = 1;
         }
     }   

    if(1 != $pages)
     {
         echo "<div class='pagination pagination-centered'><ul>";
         if($paged > 1) echo "<li><a class='prev' href='".get_pagenum_link($paged - 1)."'><i class='icon-double-angle-left'></i></a></li>";

         for ($i=1; $i <= $pages; $i++)
         {
             if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems ))
             {
                 echo ($paged == $i)? "<li class='active'><a href='".get_pagenum_link($i)."'>".$i."</a></li>":"<li><a href='".get_pagenum_link($i)."' >".$i."</a></li>";
             }
         }

         if ($paged < $pages) echo "<li><a class='next' href='".get_pagenum_link($paged + 1)."'><i class='icon-double-angle-right'></i></a></li>"; 
         echo "</ul></div>\n";
     }
}

function kriesi_breadcrumb() {
        global $post;
        echo '<ul class="breadcrumbs">';
        
         if ( !is_front_page() ) {
        echo '<li><a href="';
        echo home_url();
        echo '">'.__('Home', 'infinite-framework');
        echo "</a></li>";
        }
        
        if ( is_category() || is_single() && !is_singular('portfolio')) {
            $category = get_the_category();
            if(isset($category[0])){
                $ID = $category[0]->cat_ID;
                echo '<li>'.get_category_parents($ID, TRUE, '', FALSE ).'</li>';
            }
        }

        if(is_singular('portfolio')) {
            echo get_the_term_list($post->ID, 'portfolio_category', '<li>', ' - ', '</li>');   
        }

        if(is_home()) { echo '<li>'.of_get_option('blog_title', 'Blog').'</li>'; }
        if(is_single() || is_page()) { echo '<li>'.get_the_title().'</li>'; }
        if(is_tag()){ echo '<li>'."Tag: ".single_tag_title('',FALSE).'</li>'; }
        if(is_404()){ echo '<li>'.__("404 - Page not Found", 'infinite-framework').'</li>'; }
        if(is_search()){ echo '<li>'.__("Search", 'infinite-framework').'</li>'; }
        if(is_year()){ echo '<li>'.get_the_time('Y').'</li>'; }
        //if(is_bbpress()) {print_r(bbp_breadcrumb());}

        echo "</ul>";
}

function colourBrightness($hex, $percent) {
    $hash = '';
    if (stristr($hex,'#')) {
        $hex = str_replace('#','',$hex);
        $hash = '#';
    }
    $rgb = array(hexdec(substr($hex,0,2)), hexdec(substr($hex,2,2)), hexdec(substr($hex,4,2)));
    for ($i=0; $i<3; $i++) {
        if ($percent > 0) {
            $rgb[$i] = round($rgb[$i] * $percent) + round(255 * (1-$percent));
        } else {
            $positivePercent = $percent - ($percent*2);
            $rgb[$i] = round($rgb[$i] * $positivePercent) + round(0 * (1-$positivePercent));
        }
        if ($rgb[$i] > 255) {
            $rgb[$i] = 255;
        }
    }
    $hex = '';
    for($i=0; $i < 3; $i++) {
        $hexDigit = dechex($rgb[$i]);
        if(strlen($hexDigit) == 1) {
        $hexDigit = "0" . $hexDigit;
        }
        $hex .= $hexDigit;
    }
    return $hash.$hex;
}


function hextoRgb($hex){
    if (stristr($hex,'#')) {
        $hex = str_replace('#','',$hex);
        $hash = '#';
    }
    $rgb = array(hexdec(substr($hex,0,2)), hexdec(substr($hex,2,2)), hexdec(substr($hex,4,2)));
    return $rgb;
}


function wpex_fix_shortcodes($content){   
    $array = array (
        '<p>[' => '[', 
        ']</p>' => ']', 
        ']<br />' => ']'
    );

    $content = strtr($content, $array);
    return $content;
}
add_filter('the_content', 'wpex_fix_shortcodes');

/*AJAX FUNCTIONS*/

add_action('wp_ajax_infinite_ajax_import_data', 'infinite_ajax_import_data');

if(!function_exists('infinite_ajax_import_data')){
    function infinite_ajax_import_data(){
        include 'framework/importer/infinite-importer.php';
        die('success');
    }
}

add_action('optionsframework_after', 'infinite_admin_custom_modal');

function infinite_admin_custom_modal(){
    echo '<div id="infinite_admin_modal"><a href="#" id="infinite_admin_modal_close">close</a><div><img src="'.get_template_directory_uri().'/images/loading_dark.gif"><h3>Importing dummy data, please wait... <br>This may take a few minutes</h3></div></div>';
}

add_filter( 'http_request_args', 'pixgridder_prevent_update_check', 10, 2 );
function pixgridder_prevent_update_check( $r, $url ) {

    //if ( 0 === strpos( $url, 'https://api.wordpress.org/plugins/update-check/' ) ) {

    if ( preg_match('/https?:\/\/api.wordpress.org\/plugins\/update-check\//', $url) ) {
        $my_plugin = 'pixgridder/pixgridder.php';
        $plugins = json_decode( $r['body']['plugins'] );
        
        unset( $plugins->plugins->$my_plugin );

        foreach ($plugins->active as $ind => $value) {
            if($value === 'pixgridder/pixgridder.php'){
                unset($plugins->active->$ind);
            }
        }

        $r['body']['plugins'] = json_encode( $plugins );
    }
    return $r;
}

remove_filter( 'the_content', 'wpautop' );

?>