<?php
/*	
*	---------------------------------------------------------------------
*	Add custom post type for portfolio
*	--------------------------------------------------------------------- 
*/

 
// Register portfolio post type
add_action( 'init', 'register_cpt_portfolio' );

function register_cpt_portfolio() {

    $labels = array( 
        'name' => __( 'Portfolio Items', 'csb-admin' ),
        'singular_name' => __( 'Portfolio Items', 'csb-admin' ),
        'add_new' => __( 'Add New', 'csb-admin' ),
        'add_new_item' => __( 'Add New Item', 'csb-admin' ),
        'edit_item' => __( 'Edit Item', 'csb-admin' ),
        'new_item' => __( 'New Portfolio Item', 'csb-admin' ),
        'view_item' => __( 'View Portfolio Item', 'csb-admin' ),
        'search_items' => __( 'Search in Portfolio', 'csb-admin' ),
        'not_found' => __( 'No portfolio found', 'csb-admin' ),
        'not_found_in_trash' => __( 'No Items found in Trash', 'csb-admin' ),
        'parent_item_colon' => __( 'Parent Portfolio:', 'csb-admin' ),
        'menu_name' => __( 'Portfolio', 'csb-admin' ),
    );

    $args = array( 
        'labels' => $labels,
        'hierarchical' => false,
        'supports' => array( 'title', 'editor', 'thumbnail', 'comments' ),
        'public' => true,
        'show_ui' => true,
        'show_in_menu' => true,
        'menu_position' => 20,
		'menu_icon' => CBES_IMAGES . '/wp-portfolio-icon.png',
        
        'show_in_nav_menus' => true,
        'publicly_queryable' => true,
        'exclude_from_search' => false,
        'has_archive' => true,
        'query_var' => true,
        'can_export' => true,
        'rewrite' => array('slug' => 'portfolio-item'),
        'capability_type' => 'post'
    );

    register_post_type( 'portfolio', $args );
}

// Register custom taxonomie
add_action( 'init', 'create_portfolio_taxonomies', 0 );

function create_portfolio_taxonomies() 
{
// Add new taxonomy, NOT hierarchical (like tags)
  $labels = array(
    'name' => __( 'Category', 'csb-admin' ),
    'singular_name' => __( 'Category', 'csb-admin' ),
    'search_items' =>  __( 'Search Categories', 'csb-admin' ),
    'all_items' => __( 'All Categories', 'csb-admin' ),
    'parent_item' => __( 'Parent Category', 'csb-admin' ),
    'parent_item_colon' => __( 'Parent Category:', 'csb-admin' ),
    'edit_item' => __( 'Edit Category', 'csb-admin' ), 
    'update_item' => __( 'Update Category', 'csb-admin' ),
    'add_new_item' => __( 'Add New Category', 'csb-admin' ),
    'new_item_name' => __( 'New Category Name', 'csb-admin' ),
    'menu_name' => __( 'Categories', 'csb-admin' ),
  ); 	

  register_taxonomy('portfolio_category',array('portfolio'), array(
    'hierarchical' => true,
    'labels' => $labels,
    'show_ui' => true,
    'query_var' => true,
	'rewrite' => true  
	));  
}

// Custom portfolio column
add_filter('manage_edit-portfolio_columns', 'add_new_portfolio_columns');

function add_new_portfolio_columns($gallery_columns) {
	$new_columns['cb'] = '<input type="checkbox" />';
 
	$new_columns['thumbnail'] = __('Thumbnail', 'csb-admin' );
	$new_columns['title'] = __('Title', 'csb-admin');
	$new_columns['author'] = __('Author', 'csb-admin' );
 
	$new_columns['portfolio_categories'] = __('Categories', 'csb-admin' );
 
	$new_columns['date'] = __('Date', 'csb-admin');
	 
	return $new_columns;
}

add_action('manage_portfolio_posts_custom_column', 'manage_portfolio_columns', 10, 2);
 
function manage_portfolio_columns($column_name) {
	global $post;
	switch ($column_name) {
	
	case 'thumbnail':
		echo get_the_post_thumbnail( $post->ID, 'thumbnail' );
	break;
	
	case 'portfolio_categories':
		$terms = wp_get_post_terms($post->ID, 'portfolio_category');  
		foreach ($terms as $term) {  
			echo $term->name .'&nbsp;&nbsp; ';  
		}  
	break;
	
	} // end switch
}	

?>