<?php
/**
 * Initialize the custom theme options.
 */
add_action( 'admin_init', 'custom_theme_options' );

/**
 * Build the custom settings & update OptionTree.
 */
function custom_theme_options() {
  /**
   * Get a copy of the saved settings array. 
   */
  $saved_settings = get_option( 'option_tree_settings', array() );
  
  /**
   * Custom settings array that will eventually be 
   * passes to the OptionTree Settings API Class.
   */
  $custom_settings = array( 
    'contextual_help' => array( 
      'sidebar'       => ''
    ),
    'sections'        => array( 
      array(
        'id'          => 'general_default',
        'title'       => 'General options'
      ),
      array(
        'id'          => 'header_area_heading',
        'title'       => 'Header options'
      ),
      array(
        'id'          => 'styling_options',
        'title'       => 'Styling options'
      ),
      array(
        'id'          => 'typography_heading',
        'title'       => 'Typography'
      ),
	  array(
        'id'          => 'contact_info',
        'title'       => 'Contact Info'
      ),
	   array(
        'id'          => 'social_media',
        'title'       => 'Social Media'
      ),
      array(
        'id'          => 'footer_options',
        'title'       => 'Footer Options'
      ),
      array(
        'id'          => 'blog_general_options',
        'title'       => 'Blog options'
      ),
      array(
        'id'          => 'css',
        'title'       => 'Custom CSS'
      )
    ),
    'settings'        => array( 
     
      array(
        'id'          => 'favicon',
        'label'       => 'Custom favicon',
        'desc'        => 'Add custom favicon (16px x 16px)',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general_default',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'iphone_icon',
        'label'       => 'Apple iPhone icon',
        'desc'        => 'Icon for Apple iPhone (57px x 57px). This icon is used for Bookmark on Home screen.',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general_default',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'iphone_retina_icon',
        'label'       => 'Apple iPhone retina icon',
        'desc'        => 'Icon for Apple iPhone retina (114px x114px). This icon is used for Bookmark on Home screen.',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general_default',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'ipad_icon',
        'label'       => 'Apple iPad icon',
        'desc'        => 'Icon for Apple iPad (72px x 72px). This icon is used for Bookmark on Home screen.',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general_default',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'ipad_retina_icon',
        'label'       => 'Apple iPad retina icon',
        'desc'        => 'Icon for Apple iPad retina (144px x 144px). This icon is used for Bookmark on Home screen.',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general_default',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'login_logo',
        'label'       => 'Custom WP admin login logo',
        'desc'        => 'Upload a custom logo for Wordpress login page.',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general_default',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ), 
	  array(
        'id'          => 'analytics_code',
        'label'       => 'Analytics code',
        'desc'        => 'Paste your Google Analytics or other tracking code in text area.',
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'general_default',
        'rows'        => '6',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  
      array(
        'id'          => 'logo_options_title',
        'label'       => 'Logo options title',
        'desc'        => '<h1>Logo options</h1>',
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'header_area_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'logo_upload',
        'label'       => 'Logo upload',
        'desc'        => 'Click Upload button to insert the image. Make sure to press File URL in link field before pressing Send to OptionTree. You may also directly paste background image url into the input field.',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'header_area_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'retina_logo_upload',
        'label'       => 'Retina logo upload',
        'desc'        => 'Retina logo should be 2x the size of default logo keeping the aspect ratio!',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'header_area_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'logo_margin_top',
        'label'       => 'Logo margin top',
        'desc'        => 'Logo margin from top. Remember to add px value after the number. Example: 10px or -10px',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'header_area_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'logo_margin_left',
        'label'       => 'Logo margin left',
        'desc'        => 'Logo margin from left. Remember to add px value after the number. Example: 10px or -10px',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'header_area_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'logo_margin_bottom',
        'label'       => 'Logo margin bottom',
        'desc'        => 'Logo margin from bottom. Remember to add px value after the number. Example: 10px or -10px',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'header_area_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'logo_margin_right',
        'label'       => 'Logo margin right',
        'desc'        => 'Logo margin from right. Remember to add px value after the number. Example: 10px or -10px',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'header_area_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  
	  array(
        'id'          => 'paste_code_or_image',
        'label'       => 'Advertising Options for Header',
        'desc'        => '<h1>Advertising Options for Header</h1>',
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'header_area_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'top_banner_code',
        'label'       => 'Top Banner Ad',
        'desc'        => 'Paste your Adsense, BSA or other ad code here to show ads on top banner.',
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'header_area_heading',
        'rows'        => '6',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'paste_image',
        'label'       => 'Or',
        'desc'        => '<h1 style="background: #ff847f;text-shadow: none;color: #fff !important;border: 1px solid #e4453f;">Paste code above (OR) Add images below</h1>',
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'header_area_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'phone_ad_image',
        'label'       => 'Phones (0 - 767px):',
        'desc'        => 'Recommended Size (468x60). Automatically adjust mobile devices.',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'header_area_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'phone_ad_link',
        'label'       => 'Phones Ad Link:',
        'desc'        => 'Phones Link',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'header_area_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'ipad_por_image',
        'label'       => 'iPad Portrait(768 - 1018px):',
        'desc'        => 'Recommended Size (468x60) for iPad Portrait',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'header_area_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'ipad_por_link',
        'label'       => 'iPad Portrait Ad Link:',
        'desc'        => 'iPad Portrait Ad Link',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'header_area_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'ipad_lan_image',
        'label'       => 'iPad Landscape (1019 - 1199px):',
        'desc'        => 'Recommended Size (468x60) for iPad Landscape',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'header_area_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'ipad_lan_link',
        'label'       => 'iPad Landscape Ad Link:',
        'desc'        => 'iPad Landscape Ad Link',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'header_area_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'desktop_ad_image',
        'label'       => 'Desktop(1200px +):',
        'desc'        => 'Recommended Size (728x90) for Desktop',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'header_area_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'desktop_ad_link',
        'label'       => 'Desktop Ad Link:',
        'desc'        => 'Desktop Ad Link',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'header_area_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  	  
	  array(
        'id'          => 'general_color_scheme',
        'label'       => 'General Color Scheme',
        'desc'        => '<h1>General Color Scheme</h1>',
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'styling_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'general_color',
        'label'       => 'General theme color',
        'desc'        => 'This will be general color scheme for your website. Click input field for colorpicker.',
        'std'         => '#2da5da',
        'type'        => 'colorpicker',
        'section'     => 'styling_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'bor_color',
        'label'       => 'Border Colors',
        'desc'        => 'This will be border color scheme for your website. Click input field for colorpicker.',
        'std'         => '#d9d9d9',
        'type'        => 'colorpicker',
        'section'     => 'styling_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'content_text_color',
        'label'       => 'Body text color',
        'desc'        => 'Click input field for colorpicker or enter your custom value',
        'std'         => '#727272',
        'type'        => 'colorpicker',
        'section'     => 'styling_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'menu_text_color',
        'label'       => 'Menu text color',
        'desc'        => 'Click input field for colorpicker or enter your custom value',
        'std'         => '#2da5da',
        'type'        => 'colorpicker',
        'section'     => 'styling_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'button_text_hover',
        'label'       => 'Text Over Color',
        'desc'        => 'Click input field for colorpicker or enter your custom value',
        'std'         => '#124257',
        'type'        => 'colorpicker',
        'section'     => 'styling_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      
      array(
        'id'          => 'copyright_bg_color',
        'label'       => 'Copyright area background color',
        'desc'        => 'Click input field for colorpicker or enter your custom value',
        'std'         => '#4c4c4c',
        'type'        => 'colorpicker',
        'section'     => 'styling_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      
      array(
        'id'          => 'copyright_font_hover_color',
        'label'       => 'Copyright text hover color',
        'desc'        => 'Click input field for colorpicker or enter your custom value',
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'styling_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      
	  array(
        'id'          => 'widget_heading_color',
        'label'       => 'Widget Heading Colors',
        'desc'        => '<h1>Widget Heading Colors</h1>',
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'styling_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'widget_title_color_sidebar',
        'label'       => 'Widget Title Color (Sidebar)',
        'desc'        => 'Click input field for colorpicker or enter your custom value. Sidebar widget title color.',
        'std'         => '#2da5da',
        'type'        => 'colorpicker',
        'section'     => 'styling_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'widget_title_color_content',
        'label'       => 'Widget Title Color (content)',
        'desc'        => 'Click input field for colorpicker or enter your custom value. Content widget title color.',
        'std'         => '#2da5da',
        'type'        => 'colorpicker',
        'section'     => 'styling_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'widget_title_color_footer',
        'label'       => 'Widget Title Color (footer)',
        'desc'        => 'Click input field for colorpicker or enter your custom value. Footer widget title color.',
        'std'         => '#2da5da',
        'type'        => 'colorpicker',
        'section'     => 'styling_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'std_heading_colors',
        'label'       => 'Heading Colors',
        'desc'        => '<h1>Heading Colors</h1>',
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'styling_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'heading_one',
        'label'       => 'H1 Color',
        'desc'        => 'Click input field for colorpicker or enter your custom value. H1 Color.',
        'std'         => '#5d5d5d',
        'type'        => 'colorpicker',
        'section'     => 'styling_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'heading_two',
        'label'       => 'H2 Color',
        'desc'        => 'Click input field for colorpicker or enter your custom value. H2 Color.',
        'std'         => '#5d5d5d',
        'type'        => 'colorpicker',
        'section'     => 'styling_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'heading_three',
        'label'       => 'H3 Color',
        'desc'        => 'Click input field for colorpicker or enter your custom value. H3 Color.',
        'std'         => '#5d5d5d',
        'type'        => 'colorpicker',
        'section'     => 'styling_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'heading_four',
        'label'       => 'H4 Color',
        'desc'        => 'Click input field for colorpicker or enter your custom value. H4 Color.',
        'std'         => '#5d5d5d',
        'type'        => 'colorpicker',
        'section'     => 'styling_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'heading_five',
        'label'       => 'H5 Color',
        'desc'        => 'Click input field for colorpicker or enter your custom value. H5 Color.',
        'std'         => '#5d5d5d',
        'type'        => 'colorpicker',
        'section'     => 'styling_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'heading_six',
        'label'       => 'H6 Color',
        'desc'        => 'Click input field for colorpicker or enter your custom value. H6 Color.',
        'std'         => '#5d5d5d',
        'type'        => 'colorpicker',
        'section'     => 'styling_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  
	  
	  array(
        'id'          => 'google_body_font',
        'label'       => 'Body font',
        'desc'        => 'Font used in theme preview: Open Sans',
        'std'         => '',
        'type'        => 'typography',
        'section'     => 'typography_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'body_font_preview',
        'label'       => 'Body font preview',
        'desc'        => 'Only font-family preview! (font-weight, letter-spacing, text-transform doesn\'t affect this preview)',
        'std'         => 'Grumpy wizards make toxic brew for the evil Queen and Jack.',
        'type'        => 'textarea-simple',
        'section'     => 'typography_heading',
        'rows'        => '1',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => 'content_preview'
      ),
	  array(
        'id'          => 'google_fonts_headings',
        'label'       => 'Heading font',
        'desc'        => 'Font used in theme preview: Open Sans',
        'std'         => '',
        'type'        => 'typography',
        'section'     => 'typography_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'content_heading_font_preview',
        'label'       => 'Content heading font preview',
        'desc'        => 'Only font-family preview! (font-weight, letter-spacing, text-transform doesn\'t affect this preview)',
        'std'         => 'Grumpy wizards make toxic brew for the evil Queen and Jack.',
        'type'        => 'textarea-simple',
        'section'     => 'typography_heading',
        'rows'        => '1',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => 'heading_preview'
      ),
      array(
        'id'          => 'google_menu_font',
        'label'       => 'Menu font',
        'desc'        => 'Font used in theme preview: Open Sans',
        'std'         => '',
        'type'        => 'typography',
        'section'     => 'typography_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => 'hide-color-field'
      ),
      array(
        'id'          => 'font_preview_1',
        'label'       => 'Menu font preview',
        'desc'        => 'Only font-family preview! (font-weight, letter-spacing, text-transform doesn\'t affect this preview)',
        'std'         => 'Grumpy wizards make toxic brew for the evil Queen and Jack.',
        'type'        => 'textarea-simple',
        'section'     => 'typography_heading',
        'rows'        => '1',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => 'menu_font_preview'
      ),

      array(
        'id'          => 'google_custom_font',
        'label'       => 'Custom font for element',
        'desc'        => 'To use custom font add CSS class - "custom-font" ( class="custom-font" ) to an element.',
        'std'         => '',
        'type'        => 'typography',
        'section'     => 'typography_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'custom_font_preview',
        'label'       => 'Custom font for element preview',
        'desc'        => 'Only font-family preview! (font-weight, letter-spacing, text-transform doesn\'t affect this preview)',
        'std'         => 'Grumpy wizards make toxic brew for the evil Queen and Jack.',
        'type'        => 'textarea-simple',
        'section'     => 'typography_heading',
        'rows'        => '1',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => 'custom_font_preview'
      ),
      array(
        'id'          => 'font_sizes',
        'label'       => 'Font sizes',
        'desc'        => '<h1>Change font sizes</h1>',
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'typography_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'content_text_font_size',
        'label'       => 'Body font size',
        'desc'        => 'Remember to add "px" at the end. Example: 14px 
<br /> Leave blank for default value.',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'typography_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'menu_font_size',
        'label'       => 'Menu font size',
        'desc'        => 'Remember to add "px" at the end. Example: 14px 
<br /> Leave blank for default value.',
        'std'         => '14px',
        'type'        => 'text',
        'section'     => 'typography_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'page_title_font_size',
        'label'       => 'Page title font size',
        'desc'        => 'Remember to add "px" at the end. Example: 14px 
<br /> Leave blank for default value.',
        'std'         => '20px',
        'type'        => 'text',
        'section'     => 'typography_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'h1_size',
        'label'       => 'H1 font size',
        'desc'        => 'Remember to add "px" at the end. Example: 38px 
<br /> Leave blank for default value. Defaut value: 30px',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'typography_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'h2_size',
        'label'       => 'H2 font size',
        'desc'        => 'Remember to add "px" at the end. Example: 32px 
<br /> Leave blank for default value. Defaut value: 24px',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'typography_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'h3_size',
        'label'       => 'H3 font size',
        'desc'        => 'Remember to add "px" at the end. Example: 24px 
<br /> Leave blank for default value. Defaut value: 20px',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'typography_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'h4_size',
        'label'       => 'H4 font size',
        'desc'        => 'Remember to add "px" at the end. Example: 18px 
<br /> Leave blank for default value. Defaut value: 18px',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'typography_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'h5_size',
        'label'       => 'H5 font size',
        'desc'        => 'Remember to add "px" at the end. Example: 16px 
<br /> Leave blank for default value. Defaut value: 16px',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'typography_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'h6_size',
        'label'       => 'H6 font size',
        'desc'        => 'Remember to add "px" at the end. Example: 14px 
<br /> Leave blank for default value. Defaut value: 14px',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'typography_heading',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  
	  array(
        'id'          => 'contact_info_address',
        'label'       => 'Address',
        'desc'        => 'Enter your company address here.',
        'std'         => '3214, Lorem Str, Main Area LocalHost,<br/> NY 97563',
        'type'        => 'text',
        'section'     => 'contact_info',
        'rows'        => '6',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'contact_info_telephone',
        'label'       => 'Phone Number',
        'desc'        => 'Enter your phone number here.',
        'std'         => '+61 (123) 456 789',
        'type'        => 'text',
        'section'     => 'contact_info',
        'rows'        => '6',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'contact_info_fax',
        'label'       => 'Fax Number',
        'desc'        => 'Enter your fax number here.',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'contact_info',
        'rows'        => '6',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'contact_info_email',
        'label'       => 'Email Address',
        'desc'        => 'Enter your email addresss here.',
        'std'         => 'info@observer.com',
        'type'        => 'text',
        'section'     => 'contact_info',
        'rows'        => '6',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'contact_info_site',
        'label'       => 'Website Link',
        'desc'        => 'Enter your website link here.',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'contact_info',
        'rows'        => '6',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  
	  array(
        'id'          => 'target_social',
        'label'       => 'Open New Window',
        'desc'        => 'This setting will disable open a new window of social media links.',
        'std'         => '',
        'type'        => 'checkbox',
        'section'     => 'social_media',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'disable_target_social',
            'label'       => 'Disable Open New Window',
            'src'         => ''
          )
        ),
      ),
	  array(
        'id'          => 'dribbble_url',
        'label'       => 'Dribbble',
        'desc'        => 'Dribbble Link.',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social_media',
        'rows'        => '6',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'google_url',
        'label'       => 'Google Plus',
        'desc'        => 'Google Plus Link.',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social_media',
        'rows'        => '6',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'facebook_url',
        'label'       => 'Facebook',
        'desc'        => 'Facebook Link.',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social_media',
        'rows'        => '6',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'twitter_url',
        'label'       => 'Twitter',
        'desc'        => 'Twitter Link.',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social_media',
        'rows'        => '6',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'rss_url',
        'label'       => 'RSS',
        'desc'        => 'Rss Link. Ex : http://yoursite.com/feed',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social_media',
        'rows'        => '6',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'flickr_url',
        'label'       => 'Flickr',
        'desc'        => 'Flickr Plus Link.',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social_media',
        'rows'        => '6',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'youtube_url',
        'label'       => 'Youtube',
        'desc'        => 'Youtube Link.',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social_media',
        'rows'        => '6',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  
	  array(
        'id'          => 'footer_menu',
        'label'       => 'Disable Footer Menu',
        'desc'        => 'This setting will disable footer menus from footer.',
        'std'         => '',
        'type'        => 'checkbox',
        'section'     => 'footer_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'disable_footer_menu',
            'label'       => 'Disable Footer Menu',
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'copyright_area_text',
        'label'       => 'Copyright area text',
        'desc'        => 'This text will appear on the bottom left of your website.',
        'std'         => '© 2013 All Rights Reserved. Theme by <a href="http://cyberspacebuilder.com" target="_blank"> Cyberspace Builder.</a>',
        'type'        => 'textarea-simple',
        'section'     => 'footer_options',
        'rows'        => '6',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      
	  array(
        'id'          => 'share_option_title',
        'label'       => 'Share Options',
        'desc'        => '<h1>Share options on blog posts</h1>',
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'blog_general_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'social_share_button_facebook',
        'label'       => 'Facebook',
        'desc'        => 'Disables facebook share button from the posts.',
        'std'         => '',
        'type'        => 'checkbox',
        'section'     => 'blog_general_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'disable',
            'label'       => 'Disable',
            'src'         => ''
          )
        ),
      ),
	  array(
        'id'          => 'social_share_button_twitter',
        'label'       => 'Twitter',
        'desc'        => 'Disables twitter share button from the posts.',
        'std'         => '',
        'type'        => 'checkbox',
        'section'     => 'blog_general_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'disable',
            'label'       => 'Disable',
            'src'         => ''
          )
        ),
      ),
	  array(
        'id'          => 'social_share_button_google',
        'label'       => 'Google',
        'desc'        => 'Disables google share button from the posts.',
        'std'         => '',
        'type'        => 'checkbox',
        'section'     => 'blog_general_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'disable',
            'label'       => 'Disable',
            'src'         => ''
          )
        ),
      ),
	  array(
        'id'          => 'social_share_button_linkedin',
        'label'       => 'Linkedin',
        'desc'        => 'Disables linkedin share button from the posts.',
        'std'         => '',
        'type'        => 'checkbox',
        'section'     => 'blog_general_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'disable',
            'label'       => 'Disable',
            'src'         => ''
          )
        ),
      ),
	  array(
        'id'          => 'social_share_button_pinterest',
        'label'       => 'Pinterest',
        'desc'        => 'Disables pinterest share button from the posts.',
        'std'         => '',
        'type'        => 'checkbox',
        'section'     => 'blog_general_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'disable',
            'label'       => 'Disable',
            'src'         => ''
          )
        ),
      ),
	  array(
        'id'          => 'social_share_button_email',
        'label'       => 'Email',
        'desc'        => 'Disables email share button from the posts.',
        'std'         => '',
        'type'        => 'checkbox',
        'section'     => 'blog_general_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'disable',
            'label'       => 'Disable',
            'src'         => ''
          )
        ),
      ),
	  
	  array(
        'id'          => 'post_options',
        'label'       => 'Posts Options',
        'desc'        => '<h1>Posts Options</h1>',
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'blog_general_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'featured_post_thumb',
        'label'       => 'Featured Post Thumbnail',
        'desc'        => 'Enable Featured Post Thumbnail.',
        'std'         => '',
        'type'        => 'checkbox',
        'section'     => 'blog_general_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'featured_post_thumb',
            'label'       => 'Enable Featured Post Thumbnail',
            'src'         => ''
          )
        ),
      ),
	  array(
        'id'          => 'post_thumb_style',
        'label'       => 'Post Thumbnail Style',
        'desc'        => 'Choose your blog thumbnail style. Small - for small featured image. Large - for large featured image.',
        'std'         => '',
        'type'        => 'select',
        'section'     => 'blog_general_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'large_thumb',
            'label'       => 'Large',
            'src'         => ''
          ),
          array(
            'value'       => 'small_thumb',
            'label'       => 'Small',
            'src'         => ''
          )
        ),
      ),
	  array(
        'id'          => 'about_author',
        'label'       => 'About Author',
        'desc'        => 'Show and Hide About Author Section.',
        'std'         => '',
        'type'        => 'select',
        'section'     => 'blog_general_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'show',
            'label'       => 'Show',
            'src'         => ''
          ),
          array(
            'value'       => 'hide',
            'label'       => 'Hide',
            'src'         => ''
          )
        ),
      ),
	  
	  array(
        'id'          => 'related_posts_ot_option',
        'label'       => 'Related Posts',
        'desc'        => 'Get related posts from Tags or Category.',
        'std'         => 'Hide',
        'type'        => 'select',
        'section'     => 'blog_general_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'hide',
            'label'       => 'Hide',
            'src'         => ''
          ),
		  array(
            'value'       => 'tags',
            'label'       => 'Tags',
            'src'         => ''
          ),
          array(
            'value'       => 'category',
            'label'       => 'Category',
            'src'         => ''
          )
        ),
      ),
	  array(
        'id'          => 'related_posts_ot_option_limit',
        'label'       => 'Related Posts Limit',
        'desc'        => 'Related Posts Limit option. Ex: 6',
        'std'         => '6',
        'type'        => 'text',
        'section'     => 'blog_general_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
	),
	array(
        'id'          => 'allow_comments',
        'label'       => 'Disable comments on pages',
        'desc'        => 'This setting will disable comments from pages not a posts.',
        'std'         => '',
        'type'        => 'checkbox',
        'section'     => 'blog_general_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'disable_allow_comments',
            'label'       => 'Disable Comments',
            'src'         => ''
          )
        ),
      ),
	  array(
        'id'          => 'video_icon_post',
        'label'       => 'Post video icon BG color',
        'desc'        => 'This will be video icon bg color scheme for your posts. Click input field for colorpicker.',
        'std'         => '#e56053',
        'type'        => 'colorpicker',
        'section'     => 'blog_general_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'gallery_icon_post',
        'label'       => 'Post gallery icon BG color',
        'desc'        => 'This will be gallery icon bg color scheme for your posts. Click input field for colorpicker.',
        'std'         => '#ec9344',
        'type'        => 'colorpicker',
        'section'     => 'blog_general_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'audio_icon_post',
        'label'       => 'Post audio icon BG color',
        'desc'        => 'This will be audio icon bg color scheme for your posts. Click input field for colorpicker.',
        'std'         => '#34495e',
        'type'        => 'colorpicker',
        'section'     => 'blog_general_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
	  array(
        'id'          => 'edit_icon_post',
        'label'       => 'Post standard icon BG color',
        'desc'        => 'This will be standard icon bg color scheme for your posts. Click input field for colorpicker.',
        'std'         => '#3498db',
        'type'        => 'colorpicker',
        'section'     => 'blog_general_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),

      array(
        'id'          => 'custom_css',
        'label'       => 'Custom CSS',
        'desc'        => 'Add any of your custom CSS here.',
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'css',
        'rows'        => '20',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      )
    )
  );
  
  /* allow settings to be filtered before saving */
  $custom_settings = apply_filters( 'option_tree_settings_args', $custom_settings );
  
  /* settings are not the same update the DB */
  if ( $saved_settings !== $custom_settings ) {
    update_option( 'option_tree_settings', $custom_settings ); 
  }
  
}