<?php

add_action('after_setup_theme', 'csob_after_setup_theme');

function csob_after_setup_theme() {
    csob_i18n();

    add_action('admin_menu', 'csob_admin_menu');
    add_action('init', 'csob_initial_database');
    add_action('init', 'csob_add_exceprt_page');

    require trailingslashit(get_template_directory()) . '/library/includes/widgets.php';

    add_filter('get_avatar', 'csob_get_avatar');
}
function csob_add_exceprt_page() {
	add_post_type_support( 'page', 'excerpt' );
}
function csob_admin_menu() {
    add_menu_page(
            __('Scrolling News', csob_get_domain()), constant('CSOB_THEME_NAME'), 'edit_themes', 'csob_cpanel_theme_options', '', trailingslashit(get_template_directory_uri()) . '/library/images/logo.png', 61
    );
    //General Setting Page
    $page_csob_cpanel_theme_options = add_submenu_page(
            'csob_cpanel_theme_options', __('Scrolling News', csob_get_domain()), __('Scrolling News', csob_get_domain()), 'edit_themes', 'csob_cpanel_theme_options', 'csob_cpanel_theme_options'
    );
    add_action('admin_print_scripts-' . $page_csob_cpanel_theme_options, 'csob_admin_print_scripts');
    add_action('admin_print_styles-' . $page_csob_cpanel_theme_options, 'csob_admin_print_styles');

    //Sidebar Management Page
    $page_csob_cpanel_sidebar_management = add_submenu_page(
            'csob_cpanel_theme_options', __('Sidebar Manage', csob_get_domain()), __('Sidebar Manager', csob_get_domain()), 'edit_themes', 'csob_cpanel_sidebar_management', 'csob_cpanel_sidebar_management'
    );
    add_action('admin_print_scripts-' . $page_csob_cpanel_sidebar_management, 'csob_admin_print_scripts');
    add_action('admin_print_styles-' . $page_csob_cpanel_sidebar_management, 'csob_admin_print_styles');

    //Layout Management Page
    $page_csob_cpanel_layout_management = add_submenu_page(
            'csob_cpanel_theme_options', __('Layout Manage', csob_get_domain()), __('Layout Manager', csob_get_domain()), 'edit_themes', 'csob_cpanel_layout_management', 'csob_cpanel_layout_management'
    );
    add_action('admin_print_scripts-' . $page_csob_cpanel_layout_management, 'csob_admin_print_scripts');
    add_action('admin_print_styles-' . $page_csob_cpanel_layout_management, 'csob_admin_print_styles');
}

function csob_cpanel_theme_options() {
    include trailingslashit(get_template_directory()) . '/library/includes/cpanel/theme-options.php';
}

function csob_cpanel_sidebar_management() {
    include trailingslashit(get_template_directory()) . '/library/includes/cpanel/sidebar-manager.php';
}

function csob_cpanel_layout_management() {
    include trailingslashit(get_template_directory()) . '/library/includes/cpanel/layout-manager.php';
}

function csob_admin_print_scripts() {
    $dir = get_template_directory_uri() . '/library/js';

    if (!wp_script_is('jquery'))
        wp_enqueue_script('jquery');

    wp_localize_script('jquery', 'csob_variable', csob_localize_script());

    if (!wp_script_is('wp-color-picker'))
        wp_enqueue_script('wp-color-picker');
    if (!wp_script_is('csob-uploader'))
        wp_enqueue_script('csob-colorpicker', "{$dir}/colorpicker.js", array('jquery'), NULL, TRUE);

    if (!wp_script_is('csob-admin-utils'))
        wp_enqueue_script('csob-admin-utils', "{$dir}/utils.js", array('jquery'), NULL, TRUE);

    if (!wp_script_is('csob-admin-jquery-form'))
        wp_enqueue_script('csob-admin-jquery-form', "{$dir}/jquery.form.js", array('jquery'), NULL, TRUE);

    if (!wp_script_is('csob-admin-script'))
        wp_enqueue_script('csob-admin-script', "{$dir}/script.js", array('jquery'), NULL, TRUE);

    if (!wp_script_is('csob-admin-bootstrap'))
        wp_enqueue_script('csob-admin-bootstrap', "{$dir}/bootstrap.min.js", array('jquery'), NULL, TRUE);

    if (!wp_script_is('thickbox'))
        wp_enqueue_script('thickbox', null, array('jquery'), NULL, TRUE);

    if (!wp_script_is('csob-uploader'))
        wp_enqueue_script('csob-uploader', "{$dir}/uploader.js", array('jquery'), NULL, TRUE);
}

function csob_localize_script() {
    return array(
        'AjaxUrl' => admin_url('admin-ajax.php'),
        'google_fonts' => csob_get_google_font_array()
    );
}

function csob_admin_print_styles() {
    $dir = get_template_directory_uri() . '/library/css';
    wp_enqueue_style('csob-admin-style', "{$dir}/style.css", array(), NULL);
    wp_enqueue_style('thickbox.css', '/' . WPINC . '/js/thickbox/thickbox.css', array(), NULL);
    wp_enqueue_style('open-sans-font', 'http://fonts.googleapis.com/css?family=Open+Sans:400,700,600', array(), NULL);
    if (!wp_style_is('wp-color-picker'))
        wp_enqueue_style('wp-color-picker');


    $google_fonts = csob_get_google_font_array();
    $current_heading_font = get_option('csob_theme_options_heading_font_family', array(), NULL);
    $current_content_font = get_option('csob_theme_options_content_font_family');
    $current_main_nav_font = get_option('csob_theme_options_main_nav_font_family');
    $current_wdg_sidebar_font = get_option('csob_theme_options_wdg_sidebar_font_family');
    $current_wdg_main_font = get_option('csob_theme_options_wdg_main_font_family');
    $current_wdg_footer_font = get_option('csob_theme_options_wdg_footer_font_family');
    $current_slider_font = get_option('csob_theme_options_slider_font_family');

    $load_font_array = array();
    if ($current_heading_font) {
        array_push($load_font_array, $current_heading_font);
    }
    if ($current_content_font && !in_array($current_content_font, $load_font_array)) {
        array_push($load_font_array, $current_content_font);
    }
    if ($current_main_nav_font && !in_array($current_main_nav_font, $load_font_array)) {
        array_push($load_font_array, $current_main_nav_font);
    }
    if ($current_wdg_sidebar_font && !in_array($current_wdg_sidebar_font, $load_font_array)) {
        array_push($load_font_array, $current_wdg_sidebar_font);
    }


    if ($current_wdg_main_font && !in_array($current_wdg_main_font, $load_font_array)) {
        array_push($load_font_array, $current_wdg_main_font);
    }

    if ($current_wdg_footer_font && !in_array($current_wdg_footer_font, $load_font_array)) {
        array_push($load_font_array, $current_wdg_footer_font);
    }
    if ($current_slider_font && !in_array($current_slider_font, $load_font_array)) {
        array_push($load_font_array, $current_slider_font);
    }

    foreach ($load_font_array as $current_font) {

        if ($current_font != '') {
            $google_font_family = $google_fonts[$current_font]['family'];
            $temp_font_name = str_replace(' ', '+', $google_font_family);
            $font_url = 'http://fonts.googleapis.com/css?family=' . $temp_font_name . ':300,300italic,400,400italic,700,700italic&subset=latin';
            wp_enqueue_style('Google-Font-' . $temp_font_name, $font_url, array(), NULL);
        }
    }
}

function csob_get_domain() {
    return constant('CSOB_DOMAIN');
}

function csob_i18n() {
    load_theme_textdomain(csob_get_domain(), get_template_directory() . '/languages');
}

/* =====================================================================================
 * Add Style and script for categories and post edit page
  ==================================================================================== */
add_action('admin_enqueue_scripts', 'csob_category_scripts', 10, 1);

function csob_category_scripts($hook) {
    if ($hook == 'edit-tags.php' or $hook == 'post-new.php' or $hook == 'post.php' or $hook == 'widgets.php') {
        wp_enqueue_script('jquery');
        wp_localize_script('jquery', 'csob_variable', csob_localize_script());
        wp_enqueue_script('csob-admin-script', get_template_directory_uri() . '/library/js/script.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script('csob-admin-bootstrap', get_template_directory_uri() . '/library/js/bootstrap.min.js', array('jquery'), NULL, TRUE);
        wp_enqueue_style('csob-admin-style', get_template_directory_uri() . '/library/css/style.css', array(), NULL);
         wp_enqueue_style('csob-icon-style', get_template_directory_uri() . '/css/icoMoon.css', array(), NULL);
    }
	
	// for generate automatically rating fields
    if ( 'post-new.php' == $hook || 'post.php' == $hook ) {
        wp_enqueue_script('csob-post-rating-script', get_template_directory_uri() . '/library/js/post-rating.js', array('jquery'), NULL, TRUE);
    }
}

/* =====================================================================================
 * Add Style and script for Widget page
  ==================================================================================== */
add_action('admin_enqueue_scripts', 'csob_widget_page_scripts', 10, 1);

function csob_widget_page_scripts($hook) {
    if ($hook == 'widgets.php') {
        wp_enqueue_script('jquery');
        if (!wp_script_is('thickbox'))
            wp_enqueue_script('thickbox', null, array('jquery'), NULL, TRUE);

        if (!wp_script_is('csob-uploader'))
            wp_enqueue_script('csob-uploader', get_template_directory_uri() ."/library/js/uploader.js", array('jquery'), NULL, TRUE);
        wp_enqueue_style('thickbox.css', '/' . WPINC . '/js/thickbox/thickbox.css', array(), NULL);
        wp_enqueue_style('csob-admin-style', get_template_directory_uri() . '/library/css/widget.css', array(), NULL);
        wp_enqueue_style('csob-icon-style', get_template_directory_uri() . '/css/icoMoon.css', array(), NULL);
    }
}

function csob_log($message) {
    if (WP_DEBUG === true) {
        if (is_array($message) || is_object($message)) {
            error_log(print_r($message, true));
        } else {
            error_log($message);
        }
    }
}

function csob_get_theme_info($interval) {
    $xml = new stdClass();
    $xml->version = '1.0';
    $xml->name = 'WP Observer Theme';
    $xml->download = '';
    $xml->changelog = '';

    try {
        $db_cache_field = 'csob-notifier-cache-' . csob_get_domain();
        $db_cache_field_last_updated = 'csob-notifier-last-updated-' . csob_get_domain();
        $last = get_option($db_cache_field_last_updated);
        $now = time();

        if (!$last || (( $now - $last ) > $interval)) {
            /**
             * Update in 11/09/2013
             * @since Observer 1.0
             */
            $cache = wp_remote_get( CSOB_UPDATE_URL );

            if ( ! is_wp_error( $cache ) && isset( $cache['body'] ) ) {
                $cache = $cache['body'];
            } else {
                $cache = '';
            }

            if ($cache) {
                update_option($db_cache_field, $cache);
                update_option($db_cache_field_last_updated, time());
            }
            $notifier_data = get_option($db_cache_field);
        } else {
            $notifier_data = get_option($db_cache_field);
        }

        $xml = simplexml_load_string($notifier_data);
    } catch (Exception $e) {
        error_log($e);
    }
    return $xml;
}

function csob_get_avatar($avatar) {
    $avatar = str_replace('"', "'", $avatar);
    return str_replace("class='", "class='author-avatar ", $avatar);
}
