<?php
add_action('after_setup_theme', 'csob_front_after_setup_theme');

function csob_front_after_setup_theme() {
    add_theme_support('post-formats', array('gallery', 'audio', 'video'));
    add_theme_support('post-thumbnails');
    add_theme_support('loop-pagination');
    add_theme_support('automatic-feed-links');
    add_theme_support('editor_style');
    add_editor_style('editor-style.css');

    global $content_width;
    if ( ! isset( $content_width ) ) {
        $content_width = 795;
    }

    register_nav_menus(array(
        'main-nav'   => __( 'Main Menu', csob_get_domain() ),
        'footer-nav' => __( 'Footer Menu', csob_get_domain() )
    ));

    if (!is_admin()) {
        add_action('wp_enqueue_scripts', 'csob_front_enqueue_scripts');
        add_action('wp_footer', 'csob_footer');
        add_action('wp_head', 'csob_head');
        add_filter('widget_text', 'do_shortcode');
        add_filter('the_category', 'csob_the_category');
        add_filter('get_the_excerpt', 'csob_get_the_excerpt');
        add_filter('post_class', 'csob_post_class');
        add_filter('body_class', 'csob_body_class');
        add_filter('wp_nav_menu_items', 'csob_add_icon_home_menu', 10, 2);
        // add_filter('comment_reply_link', 'csob_comment_reply_link');
        // add_filter('edit_comment_link', 'csob_edit_comment_link');
        add_filter('wp_tag_cloud', 'csob_tag_cloud');
        add_filter('excerpt_length', 'csob_custom_excerpt_length');
        add_filter('excerpt_more', 'csob_custom_excerpt_more');
    } else {
        add_action('show_user_profile', 'csob_edit_user_profile');
        add_action('edit_user_profile', 'csob_edit_user_profile');
        add_action('personal_options_update', 'csob_edit_user_profile_update');
        add_action('edit_user_profile_update', 'csob_edit_user_profile_update');
        add_filter('image_size_names_choose', 'csob_image_size_names_choose');
    }

    csob_add_image_sizes();
}

function csob_tag_cloud($out) {

    $matches = array();
    $pattern = '/<a[^>]*?>([\\s\\S]*?)<\/a>/';
    preg_match_all($pattern, $out, $matches);

    $htmls = $matches[0];
    $texts = $matches[1];
    $new_html = '';
    for ($index = 0; $index < count($htmls); $index++) {

        $new_html.= preg_replace('#(<a.*?(href=\'.*?\').*?>).*?(</a>)#', '<a '.'$2'.'>' . $texts[$index] . '$3' . ' ', $htmls[$index]);
    }

    return $new_html;
}

function csob_comment_reply_link($link) {
    return str_replace('comment-reply-link', 'comment-reply-link small-button green-button', $link);
}

function csob_edit_comment_link($link) {
    return str_replace('comment-edit-link', 'comment-edit-link small-button green-button', $link);
}

function csob_post_class($classes) {
    if (is_single()) {
        $classes[] = 'entry-box';
        $classes[] = 'clearfix';
    }
    return $classes;
}

function csob_body_class($classes) {
    $template_setting = csob_get_template_setting();

    if (is_front_page()) {
        $classes[] = 'home-page';
    } else {
        $classes[] = 'sub-page';
    }

    if ( is_404() ) {
        return $classes;
    }

    switch ($template_setting['layout_id']) {
        case 'single-right-sidebar':
            break;
    }

    return $classes;
}

function csob_footer() {
    wp_nonce_field('csob_set_view_count', 'csob_set_view_count_wpnonce', false);
	wp_nonce_field('csob_set_user_rating', 'csob_set_user_rating_wpnonce', false);

    $csob_theme_options_tracking_code = get_option('csob_theme_options_tracking_code');
    if (!empty($csob_theme_options_tracking_code)) {
        echo htmlspecialchars_decode(stripslashes($csob_theme_options_tracking_code));
    }
}

function csob_front_enqueue_scripts() {
    if (!is_admin()) {
        global $wp_styles, $is_IE;

        $dir = get_template_directory_uri();

        /* STYLESHEETs */

        wp_enqueue_style('csob-bootstrap', $dir . '/css/bootstrap.css', array(), NULL, 'screen');
        wp_enqueue_style('csob-icoMoon', $dir . '/css/icoMoon.css', array(), NULL);
        wp_enqueue_style('csob-superfish', $dir . '/css/superfish.css', array(), NULL, 'screen');
        wp_enqueue_style('csob-prettyPhoto', $dir . '/css/prettyPhoto.css', array(), NULL, 'screen');
        wp_enqueue_style('csob-flexlisder', $dir . '/css/flexslider.css', array(), NULL, 'screen');
		
        wp_enqueue_style('csob-mCustomScrollbar', $dir . '/css/jquery.mCustomScrollbar.css', array(), NULL, 'screen');
		
		wp_enqueue_style('csob-awesome-weather', $dir . '/css/awesome-weather.css', array(), NULL, 'screen');

        wp_enqueue_style('csob-style', get_stylesheet_uri(), array(), NULL);
		wp_enqueue_style('csob-hover-style', $dir . '/css/hover.css', array(), NULL, 'screen');
        wp_enqueue_style('csob-extra-style', $dir . '/css/extra.css', array(), NULL);
        wp_enqueue_style('csob-bootstrap-responsive', $dir . '/css/bootstrap-responsive.css', array(), NULL);
        wp_enqueue_style('csob-responsive', $dir . '/css/responsive.css', array(), NULL);

        if ( $is_IE ) {
            wp_register_style('csob-ie', $dir . '/css/ie.css', array(), NULL);
            $wp_styles->add_data('csob-ie', 'conditional', 'lt IE 9');
            wp_enqueue_style('csob-ie');
        }

        /* JAVASCRIPTs */
        wp_enqueue_script('csob-google-api', 'http://ajax.googleapis.com/ajax/libs/webfont/1.4.7/webfont.js', array(), NULL, TRUE);
        wp_enqueue_script('csob-google-fonts', $dir . '/js/google-fonts.js', array('csob-google-api'), NULL, TRUE);

        $google_fonts = csob_get_google_font_array();
        $current_heading_font = get_option('csob_theme_options_heading_font_family');
        $current_content_font = get_option('csob_theme_options_content_font_family');
        $current_main_nav_font = get_option('csob_theme_options_main_nav_font_family');
        $current_wdg_sidebar_font = get_option('csob_theme_options_wdg_sidebar_font_family');
        $load_font_array = array();

        // heading font family
        if ($current_heading_font && ! in_array($current_heading_font, $load_font_array)) {
            array_push($load_font_array, $current_heading_font);
        }

        // content font family
        if ($current_content_font && ! in_array($current_content_font, $load_font_array)) {
            array_push($load_font_array, $current_content_font);
        }

        // main menu font family
        if ($current_main_nav_font && ! in_array($current_main_nav_font, $load_font_array)) {
            array_push($load_font_array, $current_main_nav_font);
        }

        // widget title font family  
        if ($current_wdg_sidebar_font && ! in_array($current_wdg_sidebar_font, $load_font_array)) {
            array_push($load_font_array, $current_wdg_sidebar_font);
        }

        foreach ($load_font_array as $current_font) {
            if ($current_font != '') {
                $google_font_family = $google_fonts[$current_font]['family'];
                $temp_font_name = str_replace(' ', '+', $google_font_family);
                $font_url = 'http://fonts.googleapis.com/css?family=' . $temp_font_name . ':300,300italic,400,400italic,700,700italic&subset=latin';
                wp_enqueue_style('Google-Font-' . $temp_font_name, $font_url);
            }
        }

        if ($is_IE) {
            wp_enqueue_script('csob-html5', 'http://html5shim.googlecode.com/svn/trunk/html5.js', array(), NULL, TRUE);
            wp_enqueue_script('csob-pieie678', $dir . '/js/PIE_IE678.js', array(), NULL, TRUE);
        }
        wp_enqueue_script('csob-modernizr', $dir . '/js/modernizr.custom.js');
        wp_enqueue_script('jquery');
        wp_localize_script('jquery', 'csob_front_variable', csob_front_localize_script());
        
        /**
         * Fix: Superfish conflicts with WP admin bar for WordPress < 3.6
         * @author joeldbirch
         * @link https://github.com/joeldbirch/superfish/issues/14
         * @filesource https://github.com/briancherne/jquery-hoverIntent 
         */
        global $wp_version;
        if(version_compare($wp_version,'3.6','<')) {
            wp_deregister_script('hoverIntent');
            wp_register_script('hoverIntent', $dir . '/js/jquery.hoverIntent.js', array('jquery'), 'r7');
        }

        wp_enqueue_script('csob-superfish-js', $dir . '/js/superfish.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script('csob-retina', $dir . '/js/retina.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script('csob-bootstrap-js', $dir . '/js/bootstrap.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script('csob-flexlisder-js', $dir . '/js/jquery.flexslider-min.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script('csob-carouFredSel', $dir . '/js/jquery.carouFredSel-6.0.4-packed.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script('csob-jflickrfeed', $dir . '/js/jflickrfeed.min.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script('csob-prettyPhoto-js', $dir . '/js/jquery.prettyPhoto.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script('csob-tweetable-js', $dir . '/js/tweetable.jquery.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script('csob-timeago-js', $dir . '/js/jquery.timeago.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script('csob-jquery-validate', $dir . '/js/jquery.validate.min.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script('csob-jquery-form', $dir . '/js/jquery.form.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script('csob-jquery-ui', 'http://ajax.googleapis.com/ajax/libs/jqueryui/1.10.3/jquery-ui.min.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script('csob-mCustomScrollbar', $dir . '/js/jquery.mCustomScrollbar.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script('csob-modernizr-transitions', $dir . '/js/modernizr-transitions.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script('csob-jquery-isotope', $dir . '/js/jquery.isotope.min.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script('csob-set-view-count', $dir . '/js/set-view-count.js', array('jquery'), NULL, TRUE);
        wp_enqueue_script('csob-custom', $dir . '/js/custom.js', array('jquery'), NULL, TRUE);

        if (is_single() || is_page()) {
            wp_enqueue_script('comment-reply');
        }
		
		if ( is_single() ) {
            wp_enqueue_script('csob-user-rating-script', $dir . '/js/csob-user-rating.js', array('jquery'), null, true);
        }
    }
}

function csob_front_localize_script() {
    $csob_variable = array(
        'ajax' => array(
            'url' => admin_url('admin-ajax.php')
        ),
        'template' => array(
            'post_id' => (is_singular()) ? get_queried_object_id() : 0
        )
    );
    return $csob_variable;
}

function csob_the_category($thelist) {
    return $thelist;
}

/* FUNCTION */

function csob_print_page_title() {
    global $page, $paged;
    wp_title('|', TRUE, 'right');
    bloginfo('name');
    $site_description = get_bloginfo('description', 'display');
    if ($site_description && ( is_home() || is_front_page() ))
        echo " | $site_description";
    if ($paged >= 2 || $page >= 2)
        echo ' | ' . sprintf(__('Page %s', csob_get_domain()), max($paged, $page));
}

function csob_get_image_sizes() {
    $sizes = array(
        'csob-image-size-0'    => array(579, 382, TRUE, __('Flexslider Post Image (Cyberspacebuilder)', csob_get_domain())),
        'csob-image-size-1'    => array(247, 146, TRUE, __('Carousel Post Image (Cyberspacebuilder)', csob_get_domain())),
        'csob-image-size-2' => array(451, 259, TRUE, __('Popular Widget Post Image (Cyberspacebuilder)', csob_get_domain())),
        'csob-image-size-3' => array(783, 450, TRUE, __('Entry List Widget Post Image (Cyberspacebuilder)', csob_get_domain())),
        'csob-image-size-4' => array(81, 81, TRUE, __('Entry List Widget Small Post Image (Cyberspacebuilder)', csob_get_domain())),
        'csob-image-size-5' => array(276, 202, TRUE, __('Gallery Widget Post Image (Cyberspacebuilder)', csob_get_domain())),
        'csob-image-size-6' => array(496, 346, TRUE, __('Quick Sort Widget Post Image (Cyberspacebuilder)', csob_get_domain())),
        'csob-image-size-7' => array(199, 173, TRUE, __('Carousel Scroll Bar Widget Post Image (Cyberspacebuilder)', csob_get_domain())),
        'csob-image-size-8' => array(648, 430, TRUE, __('Single Post Image (Cyberspacebuilder)', csob_get_domain())),
    );

    return apply_filters('csob_get_image_sizes', $sizes);
}

function csob_add_image_sizes() {
    $sizes = csob_get_image_sizes();
    foreach ($sizes as $slug => $details) {
        add_image_size($slug, $details[0], $details[1], $details[2]);
    }
}

function csob_image_size_names_choose($sizes) {
    $csob_sizes = csob_get_image_sizes();
    foreach ($csob_sizes as $size => $image) {
        $width = ($image[0]) ? $image[0] : __('auto', csob_get_domain());
        $height = ($image[1]) ? $image[1] : __('auto', csob_get_domain());
        $sizes[$size] = $image[3] . " ({$width} x {$height})";
    }
    return $sizes;
}

function csob_set_view_count($post_id) {
    $new_view_count = 0;
    $meta_key = 'csob_' . csob_get_domain() . '_total_view';

    $current_views = (int) get_post_meta($post_id, $meta_key, true);

    if ($current_views) {
        $new_view_count = $current_views + 1;
        update_post_meta($post_id, $meta_key, $new_view_count);
    } else {
        $new_view_count = 1;
        add_post_meta($post_id, $meta_key, $new_view_count);
    }
    return $new_view_count;
}

function csob_get_view_count($post_id) {
    $key = 'csob_' . csob_get_domain() . '_total_view';
    return csob_get_post_meta($post_id, $key, true, 'Int');
}

function csob_breadcrumb() {
    if (is_main_query()) {
        global $post, $wp_query;

        $prefix = '&nbsp;/&nbsp;';
        $current_class = 'current-page';
        $description = '';
        $breadcrumb_before = '<div class="row-fluid"><div class="span12"><div class="breadcrumb">';
        $breadcrumb_after = '</div></div></div>';
        $breadcrumb_home = ''.__( '', csob_get_domain() ).' <a href="' . home_url() . '">' . __('Home', csob_get_domain()) . '</a>';
        $breadcrumb = '';
        ?>

        <?php
        if (is_home()) {
            $breadcrumb.= $breadcrumb_home;
            $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, __('Blog', csob_get_domain()));
        } else if (is_post_type_archive('product') && jigoshop_get_page_id('shop')) {
            $breadcrumb.= $breadcrumb_home;
            $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, get_the_title(jigoshop_get_page_id('shop')));
        } else if (is_tag()) {
            $breadcrumb.= $breadcrumb_home;

            $term = get_term(get_queried_object_id(), 'post_tag');
            $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, $term->name);
        } else if (is_category()) {
            $breadcrumb.= $breadcrumb_home;

            $category_id = get_queried_object_id();
            $terms_link = explode(',', substr(get_category_parents(get_queried_object_id(), TRUE, ','), 0, (strlen(',') * -1)));
            $n = count($terms_link);
            if ($n > 1) {
                for ($i = 0; $i < ($n - 1); $i++) {
                    $breadcrumb.= $prefix . $terms_link[$i];
                }
            }
            $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, get_the_category_by_ID(get_queried_object_id()));

        } else if ( is_tax('product_cat') ) {
            $breadcrumb.= $breadcrumb_home;
            $breadcrumb.= '<a href="'.get_page_link( jigoshop_get_page_id('shop') ).'">'.get_the_title( jigoshop_get_page_id('shop') ).'</a>';
            $term = get_term_by( 'slug', get_query_var( 'term' ), get_query_var( 'taxonomy' ) );

            $parents = array();
            $parent = $term->parent;
            while ($parent):
                $parents[] = $parent;
                $new_parent = get_term_by( 'id', $parent, get_query_var( 'taxonomy' ));
                $parent = $new_parent->parent;
            endwhile;
            if( ! empty( $parents ) ):
                $parents = array_reverse($parents);
                foreach ($parents as $parent):
                    $item = get_term_by( 'id', $parent, get_query_var( 'taxonomy' ));
                    $breadcrumb .= '<a href="' . get_term_link( $item->slug, 'product_cat' ) . '">' . $item->name . '</a>';
                endforeach;
            endif;

            $queried_object = get_queried_object();
            $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, $queried_object->name);
        } else if ( is_tax( 'product_tag' ) ) {
            $breadcrumb.= $breadcrumb_home;
            $breadcrumb.= '<a href="'.get_page_link( jigoshop_get_page_id('shop') ).'">'.get_the_title( jigoshop_get_page_id('shop') ).'</a>';
            $queried_object = get_queried_object();
            $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, $queried_object->name);
        } else if (is_single()) {
            $breadcrumb.= $breadcrumb_home;

            if ( get_post_type() === 'product' ) :

                $breadcrumb .= '<a href="'.get_page_link( jigoshop_get_page_id('shop') ).'">'.get_the_title( jigoshop_get_page_id('shop') ).'</a>';

                if ($terms = get_the_terms( $post->ID, 'product_cat' )) :
                    $term = apply_filters( 'jigoshop_product_cat_breadcrumb_terms', current($terms), $terms);
                    $parents = array();
                    $parent = $term->parent;
                    while ($parent):
                        $parents[] = $parent;
                        $new_parent = get_term_by( 'id', $parent, 'product_cat');
                        $parent = $new_parent->parent;
                    endwhile;
                    if(!empty($parents)):
                        $parents = array_reverse($parents);
                        foreach ($parents as $parent):
                            $item = get_term_by( 'id', $parent, 'product_cat');
                            $breadcrumb .= '<a href="' . get_term_link( $item->slug, 'product_cat' ) . '">' . $item->name . '</a>';
                        endforeach;
                    endif;
                    $breadcrumb .= '<a href="' . get_term_link( $term->slug, 'product_cat' ) . '">' . $term->name . '</a>';
                endif;

                $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, get_the_title());

            else : 

                $categories = get_the_category(get_queried_object_id());
                if ($categories) {
                    foreach ($categories as $category) {
                        $breadcrumb.= $prefix . sprintf('<a href="%1$s">%2$s</a>', get_category_link($category->term_id), $category->name);
                    }
                }

                $post_id = get_queried_object_id();
                $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, get_the_title($post_id));

            endif;

        } else if (is_page()) {
            if (!is_front_page()) {
                $post_id = get_queried_object_id();
                $breadcrumb.= $breadcrumb_home;
                $post_ancestors = get_post_ancestors($post);
                if ($post_ancestors) {
                    $post_ancestors = array_reverse($post_ancestors);
                    foreach ($post_ancestors as $crumb)
                        $breadcrumb.= $prefix . sprintf('<a href="%1$s">%2$s</a>', get_permalink($crumb), get_the_title($crumb));
                }
                $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, get_the_title(get_queried_object_id()));
            }
        } else if (is_year() || is_month() || is_day()) {
            $breadcrumb.= $breadcrumb_home;

            $date = array('y' => NULL, 'm' => NULL, 'd' => NULL);

            $date['y'] = get_the_time('Y');
            $date['m'] = get_the_time('m');
            $date['d'] = get_the_time('j');

            if (is_year()) {
                $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, $date['y']);
            }

            if (is_month()) {
                $breadcrumb.= $prefix . sprintf('<a href="%1$s">%2$s</a>', get_year_link($date['y']), $date['y']);
                $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, date('F', mktime(0, 0, 0, $date['m'])));
            }

            if (is_day()) {
                $breadcrumb.= $prefix . sprintf('<a href="%1$s">%2$s</a>', get_year_link($date['y']), $date['y']);
                $breadcrumb.= $prefix . sprintf('<a href="%1$s">%2$s</a>', get_month_link($date['y'], $date['m']), date('F', mktime(0, 0, 0, $date['m'])));
                $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, $date['d']);
            }

        } else if (is_search()) {
            $breadcrumb.= $breadcrumb_home;

            $s = get_search_query();
            $c = $wp_query->found_posts;

            $description = sprintf(__('<span class="%1$s">Your search for "%2$s"', csob_get_domain()), $current_class, $s);
            $breadcrumb .= $prefix . $description;
        } else if (is_author()) {
            $breadcrumb.= $breadcrumb_home;
            $author_id = get_queried_object_id();
            $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</a>', $current_class, sprintf(__('Posts created by %1$s', csob_get_domain()), get_the_author_meta('display_name', $author_id)));
        } else if (is_404()) {
            $breadcrumb.= $breadcrumb_home;
            $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, __('Error 404', csob_get_domain()));
        }

        if ($breadcrumb)
            echo apply_filters('csob_breadcrumb', $breadcrumb_before . $breadcrumb . $breadcrumb_after);
    }
}

function csob_get_related_articles() {
    if (is_single()) {
        $get_by = ot_get_option('related_posts_ot_option', 'hide');
        if ('hide' != $get_by) {
            $limit = (int) ot_get_option('related_posts_ot_option_limit', 6);
            if ($limit > 0) {
                global $post;
                $taxs = array();
                if ('category' == $get_by) {
                    $cats = get_the_category(($post->ID));
                    if ($cats) {
                        $ids = array();
                        foreach ($cats as $cat) {
                            $ids[] = $cat->term_id;
                        }
                        $taxs [] = array(
                            'taxonomy' => 'category',
                            'field' => 'id',
                            'terms' => $ids
                        );
                    }
                } else {
                    $tags = get_the_tags($post->ID);
                    if ($tags) {
                        $ids = array();
                        foreach ($tags as $tag) {
                            $ids[] = $tag->term_id;
                        }
                        $taxs [] = array(
                            'taxonomy' => 'post_tag',
                            'field' => 'id',
                            'terms' => $ids
                        );
                    }
                }

                if ($taxs) {
                    $related_args = array(
                        'tax_query' => $taxs,
                        'post__not_in' => array($post->ID),
                        'posts_per_page' => $limit
                    );
                    $related_posts = new WP_Query( $related_args );
                    if ( $related_posts->have_posts() ) {
                        ?>
                        <div class="csob-related-post">
                            <h4 class="block-title"><span><?php _e( 'Related Posts', csob_get_domain() ); ?></span></h4>
                            <div class="list-carousel responsive" >
                            <ul class="csob-featured-news-carousel" data-pagination-id="#single_related_posts_pager" data-scroll-items="1">
                                <?php $post_index = 1; 
                                while ( $related_posts->have_posts() ) { 
                                    $related_posts->the_post(); 

                                    if ( 'video' == get_post_format() ) {
										$data_icon = '&#xe07e;'; // icon-film-2
										$class = 'video-icon-post';
									} elseif ( 'gallery' == get_post_format() ) {
										$data_icon = '&#xe079;'; // icon-images
										$class = 'gallery-icon-post';
									} elseif ( 'audio' == get_post_format() ) {
										$data_icon = '&#xe07b;'; // icon-music
										$class = 'audio-icon-post';
									} else {
										$data_icon = '&#xe070;'; // icon-pencil
										$class = 'edit-icon-post';
									}
                                ?>
                                    <li>
                        <article class="entry-item clearfix">
							<div class="bloglink">
                                <div class="entry-thumb">
									<a href="<?php the_permalink(); ?>"><span class="read">.</span></a>
                                <?php 
                                if ( has_post_thumbnail() ) {
                                    the_post_thumbnail( 'csob-image-size-1' ); // 247 x 146
                                } elseif ( 'video' == get_post_format() ) {
                                    $video = csob_content_get_video( get_the_content() );

                                    if ( isset( $video[0] ) ) {
                                        $video = $video[0];
                                    } else {
                                        $video = '';
                                    }

                                    if ( isset( $video['type'] ) && isset( $video['url'] ) ) {
                                        $video_thumbnail_url = csob_get_video_thumbnails_url( $video['type'], $video['url'] );
                                        echo '<img src="'.esc_url( $video_thumbnail_url ).'" alt="'.get_the_title().'">';
                                    }
                                } elseif ( 'gallery' == get_post_format() ) {
                                    $gallery_ids = csob_content_get_gallery_attachment_ids( get_the_content() );

                                    if ( ! empty( $gallery_ids ) ) {
                                        foreach ( $gallery_ids as $id ) {
                                            if ( wp_attachment_is_image( $id ) ) {
                                                echo wp_get_attachment_image( $id, 'csob-image-size-1' ); // 247 x 146
                                                break;
                                            }
                                        }
                                    }
                                } // endif has_post_thumbnail
                                ?>
                                    
                                </div>
                            <div class="entry-content">
                                <h4 class="entry-title clearfix" title="<?php the_title(); ?>"><span class="<?php echo $class; ?>" data-icon="<?php echo $data_icon; ?>"></span><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>
                            </div><!--entry-content-->
							
							<div class="meta-box for-carousel">
                                        <span class="entry-date"><?php the_time( get_option( 'date_format' ) ); ?></span>
										<?php 
                    $post_rating = round( get_post_meta( get_the_ID(), 'csob_editor_user_total_all_rating_' . csob_get_domain(), true ) );

                    if ( ! empty( $post_rating ) ) {
                    ?>
                        <ul class="csob-rating clearfix">
                            <?php
                            for ( $i = 0; $i < $post_rating; $i++ ) {
                                echo '<li><span data-icon="&#xe131;"></span></li>';
                            }
                            for ( $i = 0; $i < 5 - $post_rating; $i++ ) {
                                echo '<li><span data-icon="&#xe12f;"></span></li>';
                            }
                            ?>
                        </ul>
                    <?php } ?>										
                                    </div>
                                    <!-- meta-box -->
									
								</div><!--blog link-->
                        </article><!--entry-item-->
                    </li>
                                <?php } // endwhile ?>
                            </ul>
                            <div class="clearfix"></div>
                            <div id="single_related_posts_pager" class="pager"></div>
                            </div> <!-- list-carousel -->                            
                        </div>
                        <?php
                    } // endif
                    wp_reset_postdata();
                }
            }
        }
    }
}

function csob_get_related_portfolio() {
    if (is_singular('portfolio')) {
        $get_by = get_option('csob_theme_options_portfolio_related_get_by', 'hide');
        if ('hide' != $get_by) {
            $limit = (int) get_option('csob_theme_options_portfolio_related_limit', 3);
            if ($limit > 0) {
                global $post;
                $taxs = array();

                $terms = wp_get_post_terms($post->ID, $get_by);
                if ($terms) {
                    $ids = array();
                    foreach ($terms as $term) {
                        $ids[] = $term->term_id;
                    }
                    $taxs [] = array(
                        'taxonomy' => $get_by,
                        'field' => 'id',
                        'terms' => $ids
                    );
                }

                if ($taxs) {
                    $related_args = array(
                        'post_type' => 'portfolio',
                        'tax_query' => $taxs,
                        'post__not_in' => array($post->ID),
                        'posts_per_page' => $limit
                    );
                    $related_portfolios = new WP_Query($related_args);
                    if ($related_portfolios->have_posts()):
                        $index = 1;
                        ?>
                        <div class="csob-related-post">
                            <h3><span data-icon="&#xe014;"></span><?php _e('Related portfolios', csob_get_domain()); ?></h3>
                            <div class="list-carousel responsive">
                                <ul class="csob-related-post-carousel" id="<?php echo $carousel_id; ?>">
                                    <?php
                                    while ($related_portfolios->have_posts()):
                                        $related_portfolios->the_post();
                                        $post_url = get_permalink();
                                        $post_title = get_the_title();
                                        ?>       
                                        <li style="width: 390px;">
                                            <article class="entry-item clearfix">
                                                <div class="entry-thumb hover-effect">
                                                    <div class="mask">
                                                        <a class="link-detail" data-icon="&#xe0c2;" href="<?php the_permalink(); ?>"></a>
                                                    </div>
                                                    <?php if ( has_post_thumbnail() )
                                                        the_post_thumbnail( 'csob-image-size-1' );
                                                    ?>
                                                </div>
                                                <div class="entry-content">
                                                    <h6 class="entry-title"><a href="<?php echo $post_url; ?>"><?php echo $post_title; ?></a><span></span></h6>
                                                    <span class="entry-date clearfix"><span data-icon="&#xe00c;"></span><span><?php echo get_the_date(); ?></span></span>
                                                    <?php the_excerpt(); ?>
                                                </div><!--entry-content-->
                                            </article><!--entry-item-->
                                        </li>
                                        <?php
                                    endwhile;
                                    ?>
                                </ul>
                                <div class="clearfix"></div>
                                <?php if ($related_portfolios->post_count > 3): ?>
                                    <div class="carousel-nav clearfix">
                                        <a id="prev-4" class="carousel-prev" href="#">&lt;</a>
                                        <a id="next-4" class="carousel-next" href="#">&gt;</a>
                                    </div><!--end:carousel-nav-->
                                <?php endif; ?>
                            </div>
                        </div>
                        <?php
                    endif;
                    wp_reset_postdata();
                }
            }
        }
    }
}

function csob_get_socials_link() {

    $display_facebook_sharing_button = ot_get_option('social_share_button_facebook', 'show');
    $display_twitter_sharing_button = ot_get_option('social_share_button_twitter', 'show');
    $display_google_sharing_button = ot_get_option('social_share_button_google', 'show');
    $display_linkedin_sharing_button = ot_get_option('social_share_button_linkedin', 'show');
    $display_pinterest_sharing_button = ot_get_option('social_share_button_pinterest', 'show');
    $display_email_sharing_button = ot_get_option('social_share_button_email', 'show');

    if ( $display_facebook_sharing_button == 'show' ||
         $display_twitter_sharing_button == 'show' ||
         $display_google_sharing_button == 'show' ||
         $display_linkedin_sharing_button == 'show' ||
         $display_pinterest_sharing_button == 'show' ||
         $display_email_sharing_button == 'show' ) :

        $title = htmlspecialchars(get_the_title());
        $email_subject = htmlspecialchars(get_bloginfo('name')) . ': ' . $title;
        $email_body = __('I recommend this page: ', csob_get_domain()) . $title . __('. You can read it on: ', csob_get_domain()) . get_permalink();

        if ( has_post_thumbnail() ) {
            $post_thumbnail_id = get_post_thumbnail_id( get_the_ID() );
            $thumbnail = wp_get_attachment_image_src( $post_thumbnail_id );
        }
    ?>
		
        <ul class="social-link clearfix">
			<?php _e('Share this Post', csob_get_domain()); ?>:
            
			<span>
            <?php if ($display_facebook_sharing_button == 'show') : ?>
                <li><a href="http://www.facebook.com/share.php?u=<?php echo urlencode(get_permalink()); ?>" title="Facebook" target="_blank"><i class="moon-facebook"></i></a></li>
            <?php endif; ?>

            <?php if ($display_twitter_sharing_button == 'show') : ?>
                <li><a href="http://twitter.com/home?status=<?php echo get_the_title() . ':+' . urlencode(get_permalink()); ?>" title="Twitter" target="_blank"><i class="moon-twitter"></i></a></li>
            <?php endif; ?>

            <?php if ($display_google_sharing_button == 'show') : ?>
                <li><a href="https://plus.google.com/share?url=<?php echo urlencode(get_permalink()); ?>" title="Google" target="_blank"><i class="moon-google-plus"></i></a></li>
            <?php endif; ?>

            <?php if ($display_linkedin_sharing_button == 'show') : ?>
                <li><a href="http://www.linkedin.com/shareArticle?mini=true&amp;url=<?php echo urlencode(get_permalink()); ?>&amp;title=<?php echo urlencode(get_the_title()); ?>&amp;summary=<?php echo urlencode(get_the_excerpt()); ?>&amp;source=<?php echo urlencode(get_bloginfo('name')); ?>" title="Linkedin" target="_blank"><i class="moon-linkedin"></i></a></li>
            <?php endif; ?>

            <?php if ($display_pinterest_sharing_button == 'show') : ?>
                <li><a href="http://pinterest.com/pin/create/button/?url=<?php echo urlencode(get_permalink()); ?>&amp;media=<?php echo isset( $thumbnail[0] ) ? urlencode($thumbnail[0]) : ''; ?>&amp;description=<?php the_title(); ?>" title="Pinterest" target="_blank"><i class="moon-pinterest"></i></a></li>
            <?php endif; ?>

            <?php if ($display_email_sharing_button == 'show') : ?>
                <li><a data-icon="&#xe221;" href="mailto:?subject=<?php echo rawurlencode($email_subject); ?>&amp;body=<?php echo rawurlencode($email_body); ?>" title="Email" target="_self"></a></li>
            <?php endif; ?>
			</span>
                                
        </ul>
    <?php
    endif;
}

function csob_get_about_author() {
    if ('show' == ot_get_option('about_author', 'hide')) {
        global $post;
        $user_id = $post->post_author;
        $description = get_the_author_meta('description', $user_id);
        $email = get_the_author_meta('user_email', $user_id);
        $name = get_the_author_meta('display_name', $user_id);
        $link = trim(get_the_author_meta('user_url', $user_id));
        ?>

        <div class="about-author clearfix">
            <a class="avatar-thumb" href="<?php echo $link; ?>"><?php echo get_avatar($email, 90); ?></a>                                            
            <div class="author-content">
                <header class="clearfix">
                    <h4><?php _e('Posted by:', csob_get_domain()); ?></h4>                    
                    <a class="author-name" href="<?php echo $link; ?>"><?php echo $name; ?></a>
                    <?php
                    $social_links['facebook'] = get_user_meta($user_id, 'facebook', true);
                    $social_links['twitter'] = get_user_meta($user_id, 'twitter', true);
                    $social_links['google-plus'] = get_user_meta($user_id, 'google-plus', true);

                    if ($social_links['facebook'] || $social_links['twitter'] || $social_links['google-plus']):
                        ?>                  
                        <ul class="clearfix social-link">                      
                            <li><?php _e('Follow:', csob_get_domain()); ?></li>

                            <?php if ($social_links['facebook']): ?>
                                <li class="facebook-icon"><a target="_blank" data-icon="&#xe168;" title="<?php _e('Facebook', csob_get_domain()); ?>" href="<?php echo $social_links['facebook']; ?>"></a></li>
                            <?php endif; ?>

                            <?php if ($social_links['twitter']): ?>
                                <li class="twitter-icon"><a target="_blank" data-icon="&#xe16c;" title="<?php _e('Twitter', csob_get_domain()); ?>" class="twitter" href="<?php echo $social_links['twitter']; ?>"></a></li>
                            <?php endif; ?>

                            <?php if ($social_links['google-plus']): ?>
                                <li class="gplus-icon"><a target="_blank" data-icon="&#xe163;" title="<?php _e('Google+', csob_get_domain()); ?>" class="twitter" href="<?php echo $social_links['google-plus']; ?>"></a></li>
                            <?php endif; ?>                            

                        </ul><!--social-link-->
                    <?php endif; ?>
                </header>
                <div><?php echo $description; ?></div>
            </div><!--author-content-->
        </div><!--about-author-->
        <?php
    }
}

function csob_edit_user_profile($user) {
    ?>   
    <table class="form-table">
        <tr>
            <th><label for="facebook"><?php _e('Facebook', csob_get_domain()); ?></label></th>
            <td>
                <input type="url" name="facebook" id="facebook" value="<?php echo esc_attr(get_the_author_meta('facebook', $user->ID)); ?>" class="regular-text" /><br />
                <span class="description"><?php _e('Please enter your Facebook URL', csob_get_domain()); ?></span>
            </td>
        </tr>
        <tr>
            <th><label for="twitter"><?php _e('Twitter', csob_get_domain()); ?></label></th>
            <td>
                <input type="url" name="twitter" id="twitter" value="<?php echo esc_attr(get_the_author_meta('twitter', $user->ID)); ?>" class="regular-text" /><br />
                <span class="description"><?php _e('Please enter your Twitter URL', csob_get_domain()); ?></span>
            </td>
        </tr>  
        <tr>
            <th><label for="feedurl"><?php _e('Feed URL', csob_get_domain()); ?></label></th>
            <td>
                <input type="url" name="feedurl" id="feedurl" value="<?php echo esc_attr(get_the_author_meta('feedurl', $user->ID)); ?>" class="regular-text" /><br />
                <span class="description"><?php _e('Please enter your Feed URL', csob_get_domain()); ?></span>
            </td>
        </tr>      
        <tr>
            <th><label for="google-plus"><?php _e('Google Plus', csob_get_domain()); ?></label></th>
            <td>
                <input type="url" name="google-plus" id="google-plus" value="<?php echo esc_attr(get_the_author_meta('google-plus', $user->ID)); ?>" class="regular-text" /><br />
                <span class="description"><?php _e('Please enter your Google Plus URL', csob_get_domain()); ?></span>
            </td>
        </tr>
        <tr>
            <th><label for="flickr"><?php _e('Flickr', csob_get_domain()); ?></label></th>
            <td>
                <input type="url" name="flickr" id="flickr" value="<?php echo esc_attr(get_the_author_meta('flickr', $user->ID)); ?>" class="regular-text" /><br />
                <span class="description"><?php _e('Please enter your Flickr URL', csob_get_domain()); ?></span>
            </td>
        </tr>
    </table>
    <?php
}

function csob_edit_user_profile_update($user_id) {
    if (!current_user_can('edit_user', $user_id)) {
        return false;
    }

    update_user_meta($user_id, 'facebook', $_POST['facebook']);
    update_user_meta($user_id, 'twitter', $_POST['twitter']);
    update_user_meta($user_id, 'feedurl', $_POST['feedurl']);
    update_user_meta($user_id, 'google-plus', $_POST['google-plus']);
    update_user_meta($user_id, 'flickr', $_POST['flickr']);
}

function csob_get_the_excerpt($excerpt) {
    if (is_main_query()) {
        if (is_category() || is_tag()) {
            $limit = get_option('gs_excerpt_max_length', 100);
            if (strlen($excerpt) > $limit) {
                $break_pos = strpos($excerpt, ' ', $limit);
                $visible = substr($excerpt, 0, $break_pos);
                return balanceTags($visible);
            } else {
                return $excerpt;
            }
        } else if (is_search()) {
            $keys = implode('|', explode(' ', get_search_query()));
            return preg_replace('/(' . $keys . ')/iu', '<span class="csob-search-keyword">\0</span>', $excerpt);
        } else {
            return $excerpt;
        }
    }
}

function csob_get_template_setting() {
    $csob_setting = get_option('csob_setting');
    $setting = array();

    if (is_home()) {
        $setting = $csob_setting['home'];
    } else if (is_archive()) {
        if (is_category() || is_tag()) {
            $setting = get_option("csob_category_setting_" . get_queried_object_id(), $csob_setting['taxonomy']);
        } else {
            $setting = get_option("csob_category_setting_" . get_queried_object_id(), $csob_setting['archive']);
        }
    } else if (is_singular()) {
        if (is_singular('post')) {
            $setting = get_option("csob_post_setting_" . get_queried_object_id(), $csob_setting['post']);
        } else if (is_page()) {

            $setting = get_option("csob_page_setting_" . get_queried_object_id());
            if (!$setting) {
                if (is_front_page()) {
                    $setting = $csob_setting['front-page'];
                } else {
                    $setting = $csob_setting['page'];
                }
            }
        } else {
            $setting = $csob_setting['post'];
        }
    } else if (is_404()) {
        $setting = $csob_setting['_404'];
    } else if (is_search()) {
        $setting = $csob_setting['search'];
    }

    return $setting;
}

function csob_content_get_gallery($content, $enable_multi = false) {
    return csob_content_get_media($content, $enable_multi, array('gallery'));
}

function csob_content_get_video($content, $enable_multi = false) {
    return csob_content_get_media($content, $enable_multi, array('vimeo', 'youtube', 'evp_embed_video'));
}

function csob_content_get_audio($content, $enable_multi = false) {
    return csob_content_get_media($content, $enable_multi, array('audio', 'soundcloud'));
}

function csob_content_get_media($content, $enable_multi = false, $media_types = array()) {
    $media = array();
    $regex_matches = '';
    $regex_pattern = get_shortcode_regex();
    preg_match_all('/' . $regex_pattern . '/s', $content, $regex_matches);
    foreach ($regex_matches[0] as $shortcode) {
        $regex_matches_new = '';
        preg_match('/' . $regex_pattern . '/s', $shortcode, $regex_matches_new);

        if (in_array($regex_matches_new[2], $media_types)) :
            $media[] = array(
                'shortcode' => $regex_matches_new[0],
                'type' => $regex_matches_new[2],
                'url' => $regex_matches_new[5]
            );
            if (false == $enable_multi) {
                break;
            }
        endif;
    }

    return $media;
}

function csob_get_video_thumbnails_url($type, $url) {
    $thubnails = '';
    $matches = array();
    if ('youtube' === $type) {
        preg_match("#(?<=v=)[a-zA-Z0-9-]+(?=&)|(?<=v\/)[^&\n]+|(?<=v=)[^&\n]+|(?<=youtu.be/)[^&\n]+#", $url, $matches);
        $file_url = "http://gdata.youtube.com/feeds/api/videos/" . $matches[0] . "?v=2&alt=jsonc";
        $json = json_decode(file_get_contents($file_url));
        $thubnails = $json->data->thumbnail->hqDefault;
    } else if ('vimeo' === $type) {
        preg_match_all('#(http://vimeo.com)/([0-9]+)#i', $url, $matches);
        $imgid = $matches[2][0];
        $hash = unserialize(file_get_contents("http://vimeo.com/api/v2/video/$imgid.php"));
        $thubnails = $hash[0]['thumbnail_large'];
    }
    return $thubnails;
}

function csob_get_client_IP() {
    $IP = NULL;

    if (!empty($_SERVER['HTTP_CLIENT_IP'])) {
        //check if IP is from shared Internet
        $IP = $_SERVER['HTTP_CLIENT_IP'];
    } elseif (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {
        //check if IP is passed from proxy
        $ip_array = explode(",", $_SERVER['HTTP_X_FORWARDED_FOR']);
        $IP = trim($ip_array[count($ip_array) - 1]);
    } elseif (!empty($_SERVER['REMOTE_ADDR'])) {
        //standard IP check
        $IP = $_SERVER['REMOTE_ADDR'];
    }
    return $IP;
}

function csob_get_post_meta($pid, $key = '', $single = false, $type = 'String', $default = '') {
    $data = get_post_meta($pid, $key, $single);
    switch ($type) {
        case 'Int':
            $data = (int) $data;
            return ($data >= 0) ? $data : $default;
            break;
        default:
            return ($data) ? $data : $default;
            break;
    }
}

function csob_get_like_permission($pid) {
    $permission = 'disable';

    $key = 'csob_' . csob_get_domain() . '_like_by_' . csob_get_client_IP();
    $is_voted = csob_get_post_meta($pid, $key, true, 'Int');

    if (!$is_voted)
        $permission = 'enable';

    return $permission;
}

function csob_get_like_count($pid) {
    $key = 'csob_' . csob_get_domain() . '_total_like';
    return csob_get_post_meta($pid, $key, true, 'Int');
}

function csob_total_post_count_by_month($month, $year) {
    $args = array(
        'monthnum' => (int) $month,
        'year' => (int) $year,
    );
    $the_query = new WP_Query($args);
    return $the_query->post_count;
    ;
}

function csob_head() {
    
	

    /* =========================================================
      Main Colorscheme
      ============================================================ */
    if ( $csob_theme_options_color_code != '#2da5da' ) {

        $csob_rgba_color_code = csob_hex2rgba( $csob_theme_options_color_code );

        echo "<style>

            /* background */
            .pagination ul > li > span.current,
            .pagination ul > li > a:hover {
                background: $csob_theme_options_color_code;
}

            
			
			#main-menu > li:hover > a, #main-menu > li.current-menu-item > a {
				border-top: 5px solid $csob_theme_options_color_code;
			}


            /* border color */
            .blue-button,
            .border-button:hover,
            .csob-article-list-widget .tab-container-1 .entry-thumb a:hover,
            .csob-related-post .list-carousel ul li .entry-thumb a:hover,
            .mask:hover .play-icon,
            .csob-popular-post-widget .entry-item .entry-thumb a:hover,
            .widget_tag_cloud .tagcloud a:hover,
            #pf-items .element .entry-thumb a:hover,
            .list-container-2 ul li.active a, 
            .list-container-2 ul li:hover a,
            .list-container-3 ul li.active a, 
            .list-container-3 ul li:hover a,
            .entry-list li .entry-item .entry-thumb a:hover,
            .pagination ul > li > span.current,
            .pagination ul > li > a:hover,
            #comments-form #comment_name:focus,
            #comments-form #comment_email:focus,
            #comments-form #comment_url:focus,
            #comments-form #comment_message:focus,
            #contact-form #contact_name:focus,
            #contact-form #contact_email:focus,
            #contact-form #contact_url:focus,
            #contact-form #contact_message:focus {
                border-color: $csob_theme_options_color_code;
            }

            blockquote {
                border-left-color: $csob_theme_options_color_code;
            }

            .csob-carousel-2-widget ul li .entry-item:hover .entry-content {
                background-color: rgba( $csob_rgba_color_code[0], $csob_rgba_color_code[1], $csob_rgba_color_code[2], 0.87 );
            }

        </style>";        
    }
	
    /* =========================================================
      Font family
      ============================================================ */
    $google_fonts = csob_get_google_font_array();
    $current_heading_font = get_option('csob_theme_options_heading_font_family');
    $current_content_font = get_option('csob_theme_options_content_font_family');
    $current_main_nav_font = get_option('csob_theme_options_main_nav_font_family');
    $current_wdg_sidebar_font = get_option('csob_theme_options_wdg_sidebar_font_family');
    $load_font_array = array();

    
    if ($current_heading_font) {
        $google_font_family = $google_fonts[$current_heading_font]['family'];
        echo "<style>
         h1, h2, h3, h4, h5, h6 {
            font-family: '{$google_font_family}', sans-serif;
        }
        </style>";
    }
    if ($current_main_nav_font) {
        $google_font_family = $google_fonts[$current_main_nav_font]['family'];
        echo "<style>
        #main-menu > li > a,
        #main-menu li ul li a {
            font-family: '{$google_font_family}', sans-serif;
        }
        </style>";
    }
    if ($current_wdg_sidebar_font) {
        $google_font_family = $google_fonts[$current_wdg_sidebar_font]['family'];
        echo "<style>
        .widget .widget-title {
            font-family: '{$google_font_family}', sans-serif;
        }
        </style>";
    }


    /* =========================================================
      Font size
      ============================================================ */
    
    // heading 1 font-size
    $csob_theme_options_h1_font_size = get_option('csob_theme_options_h1_font_size');
    if ($csob_theme_options_h1_font_size) {
        echo "<style>
                    h1{
                       font-size:{$csob_theme_options_h1_font_size}px;
                   }
                   </style>";
    }

    // heading 2 font-size
    $csob_theme_options_h2_font_size = get_option('csob_theme_options_h2_font_size');
    if ($csob_theme_options_h2_font_size) {
        echo "<style>
                    h2{
                       font-size:{$csob_theme_options_h2_font_size}px;
                   }
                   </style>";
    }

    // heading 3 font-size
    $csob_theme_options_h3_font_size = get_option('csob_theme_options_h3_font_size');
    if ($csob_theme_options_h3_font_size) {
        echo "<style>
                    h3{
                       font-size:{$csob_theme_options_h3_font_size}px;
                   }
                   </style>";
    }

    // heading 4 font-size
    $csob_theme_options_h4_font_size = get_option('csob_theme_options_h4_font_size');
    if ($csob_theme_options_h4_font_size) {
        echo "<style>
                    h4,
                    #contact-box > h4{
                       font-size:{$csob_theme_options_h4_font_size}px;
                   }
                   </style>";
    }

    // heading 5 font-size
    $csob_theme_options_h5_font_size = get_option('csob_theme_options_h5_font_size');
    if ($csob_theme_options_h5_font_size) {
        echo "<style>
                    h5{
                       font-size:{$csob_theme_options_h5_font_size}px;
                   }
                   </style>";
    }

    // heading 6 font-size
    $csob_theme_options_h6_font_size = get_option('csob_theme_options_h6_font_size');
    if ($csob_theme_options_h6_font_size) {
        echo "<style>
                    h6{
                       font-size:{$csob_theme_options_h6_font_size}px;
                   }
                   </style>";
    }

    // main menu font-size
    $csob_theme_options_main_nav_font_size = get_option('csob_theme_options_main_nav_font_size');
    if ($csob_theme_options_main_nav_font_size) {
        echo "<style>
            #main-menu > li > a,
            #main-menu li ul li a {
                font-size: {$csob_theme_options_main_nav_font_size}px;
            }
        </style>";
    }
    
    // widget title font-size
    $csob_theme_options_wdg_sidebar_font_size = get_option('csob_theme_options_wdg_sidebar_font_size');
    if ($csob_theme_options_wdg_sidebar_font_size) {
        echo "<style>
        .widget .widget-title,
        .widget-area-6 .widget .widget-title, 
        .widget-area-12 .widget .widget-title,
        .top-sidebar .csob-home-slider-widget .widget-title,
        #bottom-sidebar .widget .widget-title,
        #bottom-sidebar .widget_text .widget-title,
        .top-sidebar .csob-latest-post-widget .widget-title,
        .widget-area-7 .widget .widget-title {
            font-size: {$csob_theme_options_wdg_sidebar_font_size}px;
        }
        </style>";
    }
    
    /* ================================================================================
     * Font weight
      ================================================================================ */

    // heading 1 font-weight
    $csob_theme_options_h1_font_weight = get_option('csob_theme_options_h1_font_weight');
    if ($csob_theme_options_h1_font_weight) {
        echo "<style>
         h1{
            font-weight: {$csob_theme_options_h1_font_weight};
        }
        </style>";
    }

    // heading 2 font-weight
    $csob_theme_options_h2_font_weight = get_option('csob_theme_options_h2_font_weight');
    if ($csob_theme_options_h2_font_weight) {
        echo "<style>
         h2{
            font-weight: {$csob_theme_options_h2_font_weight};
        }
        </style>";
    }

    // heading 3 font-weight
    $csob_theme_options_h3_font_weight = get_option('csob_theme_options_h3_font_weight');
    if ($csob_theme_options_h3_font_weight) {
        echo "<style>
         h3{
            font-weight: {$csob_theme_options_h3_font_weight};
        }
        </style>";
    }

    // heading 4 font-weight
    $csob_theme_options_h4_font_weight = get_option('csob_theme_options_h4_font_weight');
    if ($csob_theme_options_h4_font_weight) {
        echo "<style>
         h4{
            font-weight: {$csob_theme_options_h4_font_weight};
        }
        </style>";
    }

    // heading 5 font-weight
    $csob_theme_options_h5_font_weight = get_option('csob_theme_options_h5_font_weight');
    if ($csob_theme_options_h5_font_weight) {
        echo "<style>
         h5{
            font-weight: {$csob_theme_options_h5_font_weight};
        }
        </style>";
    }

    // heading 6 font-weight
    $csob_theme_options_h6_font_weight = get_option('csob_theme_options_h6_font_weight');
    if ($csob_theme_options_h6_font_weight) {
        echo "<style>
         h6{
            font-weight: {$csob_theme_options_h6_font_weight};
        }
        </style>";
    }

    // main menu font-weight
    $csob_theme_options_main_nav_font_weight = get_option('csob_theme_options_main_nav_font_weight');
    if ($csob_theme_options_main_nav_font_weight) {
        echo "<style>
        #main-menu > li > a,
        #main-menu li ul li a {
            font-weight: {$csob_theme_options_main_nav_font_weight};
        }
        </style>";
    }

    // widget tilte font-weight
    $csob_theme_options_wgd_sidebar_font_weight = get_option('csob_theme_options_wgd_sidebar_font_weight');
    if ($csob_theme_options_wgd_sidebar_font_weight) {
        echo "<style>
        .widget .widget-title {
            font-weight: {$csob_theme_options_wgd_sidebar_font_weight};
        }
        </style>";
    }

    /* ==================================================================================================
     * Custom CSS
     * ================================================================================================= */
    $custom_css = htmlspecialchars_decode(stripslashes(ot_get_option('custom_css')));
    if ($custom_css)
        echo "<style>{$custom_css}</style>";

    /* ==================================================================================================
     * IE8 Fix CSS3
     * ================================================================================================= */
    echo "<style>
        .search-box .search-form .search-text,
        .search-box .search-form .search-submit,
        .home-slider .flex-direction-nav a,
        .csob-carousel-widget .list-carousel ul li .entry-thumb a, 
        .csob-article-list-widget .tab-container-1 .entry-thumb a, 
        .csob-related-post .list-carousel ul li .entry-thumb a,
        .csob-social-widget ul li a,
        .csob-popular-post-widget .entry-item .entry-thumb a,
        .play-icon,
        #pf-items .element .entry-thumb a,
        .csob-social-static-widget ul li .social-icon,
        .entry-list li .entry-item .entry-thumb a,
        .csob-carousel-widget .pager a, .csob-related-post .pager a {
            behavior: url(".get_template_directory_uri()."/js/PIE.htc);
        }
    </style>";
}

/* ==============================================================================
 * Mobile Menu
  ============================================================================= */

class csob_mobile_menu extends Walker_Nav_Menu {

    function start_el(&$output, $item, $depth = 0, $args = array(), $current_object_id = 0) {
        global $wp_query;
        $indent = ( $depth ) ? str_repeat("\t", $depth) : '';

        $class_names = $value = '';

        $classes = empty($item->classes) ? array() : (array) $item->classes;
        $classes[] = 'menu-item-' . $item->ID;

        $class_names = join(' ', apply_filters('nav_menu_css_class', array_filter($classes), $item, $args));
        
        if ($depth == 0)
            $class_names = $class_names ? ' class="' . esc_attr($class_names) . ' clearfix"' : 'class="clearfix"';
        else 
            $class_names = $class_names ? ' class="' . esc_attr($class_names) . '"' : 'class=""';

        $id = apply_filters('nav_menu_item_id', 'menu-item-' . $item->ID, $item, $args);
        $id = $id ? ' id="' . esc_attr($id) . '"' : '';

        $output .= $indent . '<li' . $id . $value . $class_names . '>';

        $attributes = !empty($item->attr_title) ? ' title="' . esc_attr($item->attr_title) . '"' : '';
        $attributes .=!empty($item->target) ? ' target="' . esc_attr($item->target) . '"' : '';
        $attributes .=!empty($item->xfn) ? ' rel="' . esc_attr($item->xfn) . '"' : '';
        $attributes .=!empty($item->url) ? ' href="' . esc_attr($item->url) . '"' : '';
        if ($depth == 0) {
            $item_output = $args->before;
            $item_output .= '<h3><a' . $attributes . '>';
            $item_output .= $args->link_before . apply_filters('the_title', $item->title, $item->ID) . $args->link_after;
            $item_output .= '</a></h3>';
            $item_output .= $args->after;
        } else {
            $item_output = $args->before;
            $item_output .= '<a' . $attributes . '>';
            $item_output .= $args->link_before . apply_filters('the_title', $item->title, $item->ID) . $args->link_after;
            $item_output .= '</a>';
            $item_output .= $args->after;
        }
        $output .= apply_filters('walker_nav_menu_start_el', $item_output, $item, $depth, $args);
    }

    function start_lvl(&$output, $depth = 0, $args = array()) {
        $indent = str_repeat("\t", $depth);
        if ($depth == 0) {
            $output .= "\n$indent<span>+</span><div class='clear'></div><div class='menu-panel clearfix'><ul>";
        } else {
            $output .= '<ul>'; // indent for level 2, 3 ...
        } 
    }

    function end_lvl(&$output, $depth = 0, $args = array()) {
        $indent = str_repeat("\t", $depth);
        if ($depth == 0) {
            $output .= "$indent</ul></div>\n";
        } else {
            $output .= '</ul>';
        } 
    }

}

function csob_add_icon_home_menu($items, $args) {

    if ($args->theme_location == 'main-nav') {
        if ($args->menu_id == 'toggle-view-menu') {
            $homelink = '';
            $items = $homelink . $items;
        } else if ($args->menu_id == 'main-menu') {
            $homelink = '';
            $items = $homelink . $items;
        }
    }
    return $items;
}

function csob_custom_excerpt_length( $length ) {
    $csob_setting = csob_get_template_setting();

    if ( 'home' == $csob_setting['layout_id'] ) {
        return 25;
    }

    return $length;
}

function csob_custom_excerpt_more( $more ) {
    return '...';
}

/**
 * Convert Hex Color to RGB using PHP
 * @link http://bavotasan.com/2011/convert-hex-color-to-rgb-using-php/
 */
function csob_hex2rgba($hex, $alpha = false) {
    $hex = str_replace("#", "", $hex);

    if(strlen($hex) == 3) {
        $r = hexdec(substr($hex,0,1).substr($hex,0,1));
        $g = hexdec(substr($hex,1,1).substr($hex,1,1));
        $b = hexdec(substr($hex,2,1).substr($hex,2,1));
    } else {
        $r = hexdec(substr($hex,0,2));
        $g = hexdec(substr($hex,2,2));
        $b = hexdec(substr($hex,4,2));
    }
    if ( $alpha ) {
        return array($r, $g, $b, $alpha);
    }
    
    return array($r, $g, $b);
}

/**
 * Get gallery string ids after getting matched gallery array
 * @return array of attachment ids in gallery
 * @return empty if no gallery were found
 */
function csob_content_get_gallery_attachment_ids( $content ) {
    $gallery = csob_content_get_gallery( $content );

    if (isset( $gallery[0] )) {
        $gallery = $gallery[0];
    } else {
        return '';
    } 

    if ( isset($gallery['shortcode']) ) {
        $shortcode = $gallery['shortcode'];
    } else {
        return '';
    } 

    // get gallery string ids
    preg_match_all('/ids=\"(?:\d+,*)+\"/', $shortcode, $gallery_string_ids);
    if ( isset( $gallery_string_ids[0][0] ) ) {
        $gallery_string_ids = $gallery_string_ids[0][0];
    } else {
        return '';
    } 

    // get array of image id
    preg_match_all('/\d+/', $gallery_string_ids, $gallery_ids);
    if ( isset( $gallery_ids[0] ) ) {
        $gallery_ids = $gallery_ids[0];
    } else {
        return '';
    } 

    return $gallery_ids;
}