<?php
// register the meta box
add_action('add_meta_boxes', 'csob_edit_extra_post_fields');

function csob_edit_extra_post_fields() {
    add_meta_box(
            'csob-post-edit', // this is HTML id of the box on edit screen
            'Layout and Sidebar Options', // title of the box
            'csob_sidebar_option_box_content', // function to be called to display the checkboxes, see the function below
            'post', // on which edit screen the box should appear
            'normal', // part of page where the box should appear
            'default'      // priority of the box
    );
}

// display the metabox
function csob_sidebar_option_box_content($csob_post) {
    // Use nonce for verification
    wp_nonce_field(plugin_basename(__FILE__), 'csob_noncename');

    $csob_post_setting_key = "csob_post_setting_" . $csob_post->ID;
    $csob_setting = get_option('csob_setting');
    $csob_post_setting = get_option($csob_post_setting_key, array());
    $csob_disable = '';
    if (empty($csob_post_setting)) {
        $csob_disable = ' disabled';
        $csob_checked = '';
        $csob_checked_value = "No";
        $csob_post_setting = $csob_setting["post"];
    } else {
        $csob_checked = 'checked ="checked"';
        $csob_disable = '';
        $csob_checked_value = "Yes";
    }
    $csob_template_hierarchy = unserialize(CSOB_TEMPLATE_HIERARCHY);
    $csob_layout = unserialize(CSOB_LAYOUT);
    $csob_sidebar_position = unserialize(CSOB_SIDEBAR_POSITION);
    $csob_sidebar = get_option('csob_sidebar');
    wp_nonce_field("save_layout_setting", "nonce_id_save");
    ?>    
    <div id="csob-post-edit" class="csob-post-edit csob-content-main-box">
        <div class="csob-box-head clearfix"> 
            <input onchange="show_on_checked(jQuery(this));" autocomplete="off" type="checkbox" name="csob_custom_layout_setting" id="csob_custom_layout_setting" class="csob_custom_layout_setting" value="<?php echo $csob_checked_value; ?>" <?php echo $csob_checked; ?> >
            <label class="csob-label">Check if you would like to use custom setting</label>
        </div><!--csob-box-head-->
        <div class="csob-box-body clearfix"> 
            <div class="csob-layout-box pull-left">
                <div class="csob-select-layout-box csob-element-box">

                    <span class="csob-component-title">Select the layout</span>
                    <select name ="csob_select_layout" class="csob-layout-select"  onchange="show_onchange(jQuery(this));" autocomplete="off" <?php echo $csob_disable; ?>>
                        <?php
                        foreach ($csob_template_hierarchy['post']['layout'] as $keys => $value) {
                            echo '<option value="' . $value . '"';
                            if ($value === $csob_post_setting['layout_id']) {
                                echo 'selected="selected"';
                            }
                            echo '>' . $csob_layout[$value]['title'] . '</option>';
                        }
                        ?>
                    </select>                           
                </div><!--csob-select-layout-box-->
                <?php
                foreach ($csob_template_hierarchy['post']['layout'] as $keys => $value) {
                    foreach ($csob_layout as $layout_key => $layout_value) {
                        if ($layout_key == $value) {
                            ?>
                            <div class="<?php echo 'csob-sidebar-box-wrapper sidebar-position-' . $layout_key; ?>">
                                <?php
                                foreach ($layout_value['positions'] as $postion_key => $postion_id) {
                                    ?>
                                    <div class="csob-sidebar-box csob-element-box">
                                        <span class="csob-component-title"><?php echo $csob_sidebar_position[$postion_id]['title']; ?></span>                                               
                                        <label class="csob-label">Select sidebars</label>
                                        <?php
                                        echo '<select class="csob-sidebar-select"  autocomplete="off" ' . $csob_disable . '>';
                                        foreach ($csob_sidebar as $sidebar_list_key => $sidebar_list_value) {
                                            $__selected_sidebar = '';
                                            if ($layout_key === $csob_post_setting['layout_id']) {
                                                if ($sidebar_list_key === $csob_post_setting['sidebars'][$postion_key]) {
                                                    $__selected_sidebar = 'selected="selected"';
                                                }
                                            }
                                            echo '<option value="' . $sidebar_list_key . '" ' . $__selected_sidebar . '>' . $sidebar_list_value . '</option>';
                                            $__selected_sidebar = '';
                                        }
                                        echo '</select>';
                                        ?>
                                    </div><!--csob-sidebar-box-->
                                <?php } ?>
                            </div><!--csob-sidebar-box-wrapper-->
                            <?php
                        }
                    }
                }
                ?>
            </div><!--csob-layout-box-->
            <div class="csob-thumbnails-box pull-right">
                <?php
                foreach ($csob_template_hierarchy['post']['layout'] as $thumbnails_key => $thumbnails_value) {
                    ?>
                    <image class="responsive-img <?php echo 'csob-cpanel-thumbnails csob-cpanel-thumbnails-' . $thumbnails_value; ?>" src="<?php echo CSOB_CPANEL_IMAGE_DIR . $csob_layout[$thumbnails_value]['thumbnails']; ?>" class="img-polaroid" alt="">
                    <?php
                }
                ?>
            </div><!--csob-thumbnails-box-->
        </div><!--csob-box-body-->           
    </div><!--csob-content-box--> 
    <?php
}

add_action('save_post', 'csob_save_postdata');

// When the post is saved, saves our custom data 
function csob_save_postdata($post_id) {
    if (!isset($_POST['csob_noncename']) || !wp_verify_nonce($_POST['csob_noncename'], plugin_basename(__FILE__)))
        return;
    $post_ID = $_POST['post_ID'];
    $csob_post_setting_key = "csob_post_setting_" . $post_ID;
    if (empty($_POST['csob_custom_layout_setting'])) {
        delete_option($csob_post_setting_key);
    }
    if (!empty($_POST['csob_custom_layout_setting']) && !empty($_POST['csob_select_layout']) && !empty($_POST['sidebar'])) {
        if ($_POST['csob_custom_layout_setting'] == 'Yes') {
            $csob_new_setting = array();
            $csob_new_setting['layout_id'] = $_POST['csob_select_layout'];
            $new_sidebars = ($_POST['sidebar']);
            $csob_new_setting['sidebars'] = array();
            foreach ($new_sidebars as $__k => $__v) {
                $csob_new_setting['sidebars'][$__k] = $__v;
            }
            update_option($csob_post_setting_key, $csob_new_setting);
        }
    }
}
