<?php
/**
 * Editor Post Rating Metabox
 * @subpackage Observer
 * @since Observer 1.0
 */

add_action('add_meta_boxes', 'csob_post_rating_meta_box_add');

function csob_post_rating_meta_box_add() {
    add_meta_box('csob-post-rating-edit', __( 'Editor Rating', csob_get_domain() ), 'csob_meta_box_post_rating_cb', 'post', 'normal', 'high');
}

function csob_meta_box_post_rating_cb($post) {
    $csob_editor_post_rating = get_post_meta( $post->ID, 'csob_editor_post_rating_' . csob_get_domain(), true ); 
    
    wp_nonce_field( 'csob_post_rating_meta_box_nonce', 'csob_post_rating_meta_box_nonce' );
    
    ?>
    
    <div id="csob-rating-wrapper">
        <!-- Dynamic content area for post rating fields -->
        <?php if ( $csob_editor_post_rating ) { 
            foreach ( $csob_editor_post_rating as $index => $rating ) { ?>
                <p id="csob-rating-field-<?php echo $index; ?>" class="csob-field-wrapper" data-id="<?php echo $index; ?>">
                    <label for=""><?php _e('Rating Name:', csob_get_domain()); ?> </label>
                    <input name="csob_editor_post_rating[<?php echo $index; ?>][name]" type="text" value="<?php echo $rating['name']; ?>">
                    <select name="csob_editor_post_rating[<?php echo $index; ?>][value]">
                        <?php $csob_rating_options = array( 1, 2, 3, 4, 5 );
                        foreach ( $csob_rating_options as $value ) { ?>

                            <option value="<?php echo $value; ?>" <?php selected( $value, $rating['value'] ); ?>>
                                <?php echo $value . __( ' Star(s)', csob_get_domain() ); ?>
                            </option>

                        <?php } ?>
                    </select>
                    <button class="button csob-remove-rating"><?php _e( 'Remove', csob_get_domain() ); ?></button>
                </p> <!-- .csob-field-wrapper -->
            <?php } // endforeach
        } // endif ?>
    </div> <!-- #csob-rating-wrapper -->
    
    <p class="meta-options">
        <button id="csob-rating-add" class="button button-primary"><?php _e( 'Add', csob_get_domain() ); ?></button>
        <button id="csob-rating-remove-all" class="button"><?php _e( 'Remove All', csob_get_domain() ); ?></button>
    </p>

    <?php
}

add_action('save_post', 'csob_save_post_rating_data');

function csob_save_post_rating_data( $post_id ) {
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }
    if (!isset($_POST['csob_post_rating_meta_box_nonce']) || !wp_verify_nonce($_POST['csob_post_rating_meta_box_nonce'], 'csob_post_rating_meta_box_nonce')) {
        return;
    }
    if ( isset( $_POST['csob_editor_post_rating'] ) ) {
        $csob_editor_post_rating = $_POST['csob_editor_post_rating'];
        foreach ( $csob_editor_post_rating as $index => $rating ) {
            if ( empty( $rating['name'] ) ) {
                unset( $csob_editor_post_rating[ $index ] );
            }
        }
        
        if ( empty( $csob_editor_post_rating ) ) { 
            delete_post_meta( $post_id, 'csob_editor_post_rating_' . csob_get_domain() );
            delete_post_meta( $post_id, 'csob_editor_total_rating_' . csob_get_domain()  );
            delete_post_meta( $post_id, 'csob_user_post_rating_' . csob_get_domain()  );
            delete_post_meta( $post_id, 'csob_user_total_rating_' . csob_get_domain()  );
            delete_post_meta( $post_id, 'csob_user_total_all_rating_' . csob_get_domain()  );
        } else {
            $csob_editor_total_rating = 0;
            foreach ( $csob_editor_post_rating as $rating ) {
                $csob_editor_total_rating += $rating['value'];
            }
            $csob_editor_total_rating = $csob_editor_total_rating / count( $csob_editor_post_rating );

            // get user post rating and unset rating indexes that are not in editor rating indexes
            $csob_user_post_rating = get_post_meta( $post_id, 'csob_user_post_rating_' . csob_get_domain() , true );
            $csob_user_total_rating = get_post_meta( $post_id, 'csob_user_total_rating_' . csob_get_domain() , true );

            if ( ! empty( $csob_user_post_rating ) && ! empty( $csob_user_total_rating ) ) {
                foreach ( $csob_user_post_rating as $rating_index => $rating ) {
                    if ( ! isset( $csob_editor_post_rating[ $rating_index ] ) ) {
                        unset($csob_user_post_rating[ $rating_index ]);
                    }
                }
                foreach ( $csob_user_total_rating as $rating_index => $value ) {
                    if ( ! isset( $csob_user_post_rating[ $rating_index ] ) ) {
                        unset($csob_user_total_rating[ $rating_index ]);
                    }
                }
            } // endif

            // recalculate total all rating indexes of all users
            $total_user_all_rating = 0;
            if ( ! empty( $csob_user_total_rating ) ) {
                foreach( $csob_user_total_rating as $value ) {
                    $total_user_all_rating += $value;
                }
                $total_user_all_rating = $total_user_all_rating / count( $csob_user_total_rating );
            }

            // calculate editor and users ratings
            $csob_editor_user_total_all_rating = $csob_editor_total_rating;
            if ( ! empty( $total_user_all_rating ) ) {
                $csob_editor_user_total_all_rating = ( $csob_editor_user_total_all_rating + $total_user_all_rating ) / 2;
            }

            update_post_meta( $post_id, 'csob_editor_post_rating_' . csob_get_domain() , $csob_editor_post_rating );
            update_post_meta( $post_id, 'csob_editor_total_rating_' . csob_get_domain() , $csob_editor_total_rating );

            if ( ! empty( $csob_user_post_rating ) && ! empty( $csob_user_total_rating ) && ! empty( $total_user_all_rating ) ) {
                update_post_meta( $post_id, 'csob_user_post_rating_' . csob_get_domain() , $csob_user_post_rating );
                update_post_meta( $post_id, 'csob_user_total_rating_' . csob_get_domain() , $csob_user_total_rating );
                update_post_meta( $post_id, 'csob_user_total_all_rating_' . csob_get_domain() , $total_user_all_rating );
            } 
            // delete if empty
            // case 1: no users rated (in the beginning of time)
            // case 2: rated but editor(admin) deletes 1 or more rating indexes -> make it empty
            else { 
                delete_post_meta( $post_id, 'csob_user_post_rating_' . csob_get_domain() );
                delete_post_meta( $post_id, 'csob_user_total_rating_' . csob_get_domain() );
                delete_post_meta( $post_id, 'csob_user_total_all_rating_' . csob_get_domain() );
            }

            update_post_meta( $post_id, 'csob_editor_user_total_all_rating_' . csob_get_domain() , $csob_editor_user_total_all_rating );
        }
    } else {
        delete_post_meta( $post_id, 'csob_editor_post_rating_' . csob_get_domain() );
        delete_post_meta( $post_id, 'csob_editor_total_rating_' . csob_get_domain() );
        delete_post_meta( $post_id, 'csob_user_post_rating_' . csob_get_domain() );
        delete_post_meta( $post_id, 'csob_user_total_rating_' . csob_get_domain() );
        delete_post_meta( $post_id, 'csob_user_total_all_rating_' . csob_get_domain() );
    }
}